(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     13556,        472]*)
(*NotebookOutlinePosition[     14654,        507]*)
(*  CellTagsIndexPosition[     14610,        503]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["7. Lists III: Repetition with Lists:  Homework", "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision:  January 26 1998", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Author: YourNameGoesHere"], "Subtitle",
  CellFrame->True,
  Evaluatable->False,
  AspectRatioFixed->True,
  Background->GrayLevel[0.899992]],

Cell[CellGroupData[{

Cell[TextData["1. Iteration Towards a Fixed Point"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["One way to solve an equation of the form  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["f[x] == x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\"  is to start with some guess and just \"keep pressing the f button\" \
(i.e., ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["f[x]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["f[f[x]]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ",...).  It may happen that the successive values get closer and closer to \
one particular value.  If this is the case, we say that the sequence",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" converges",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ".   If the sequence converges, it will converge to a solution of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["f[x] == x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", called a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fixed point",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[".  Use both \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["FindRoot[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" (which will give you the solution) and iteration (with an initial guess \
somewhere close to the actual solution) to solve\n\n (a)  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Cos[x] == x ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" \n\nand\n\n (b) ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Exp[-x] == x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ".  \n\nShow a sequence of iteration values that converge to each \
solution.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2. Drunkard's Walk"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In the last homework you created a list of 10 directions in a random walk. \
 Now we'd like to record the stops that each of these steps take you to if \
you start from the origin.  For example, suppose your list of random \
directions started with ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{ {1,0},{1,0},{0,-1},...}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", then your list of stops would be ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{{0,0},{1,0},{2,0},{2,-1},...}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".\n\nWhile we could use our old list of directions (up=",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{0,1}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", right=",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{1,0}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ", and so on), let's be\na little more imaginative.  Let us say that a \
random direction is a list of two numbers, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{a,b}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[",\nwhere \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is a random Real number between ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["-1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is similarly a random Real\nnumber between ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["-1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".  (Note:  when we describe data as having (sub)elements \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", and so forth, with particular properties, we are not indicating that \
any variables, such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", should be defined.  Instead, we are simply using letters to denote \
portions of the data element.  In this instance, then, we mean that a random \
direction is any pair of random real numbers between ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["-1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", such as ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{-0.4566,0.2424}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".)",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(a) Create a function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["randDir[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" taking one argument \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" which will return a list of\nn directions, as defined above.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(b) Now create a function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["stops[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", taking one argument, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", that will give you the stops of a walk which has random directions \
given by \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["randDir[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Hint:  think in terms of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{0,0} + {a,b} + {c,d} + ...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["(c) Use the option \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotJoined->True",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in the function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ListPlot[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to get a picture of a drunkard's walk of 500 steps.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3. Indecisive Walker"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "An indecisive man is unsure about where to spend his day.  He could stay \
home, at coordinate ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{0,0}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", go to the beach at ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{100,0}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", or go to work at ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{50,87}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".  Starting from the point ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{50,44}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ", he makes a random choice about which of the three possibilities to \
pursue.  Unfortunately the man proceeds only halfway to his choice before \
having a crisis about his decision.  He stops at this crisis point, makes a \
new random choice (possibly the same as before), and heads off.  Again the \
walker proceeds only halfway to his choice before having another crisis.  The \
indecisive man spends the entire day repeating this procedure, roughly 1000 \
times.  Produce a plot simulating the location of all of the crisis points.  \
(Recall from mathematics class that the midpoint of a line segment between \
the points ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{a,b}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{c,d}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" is ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{(a+c)/2, (b+d)/2}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".)",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->"EditBar",
WindowSize->{520, 509},
WindowMargins->{{148, Automatic}, {30, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003809T?o>old</PW30fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400A7M;U0000000000060801T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 111, 2, 136, "Title",
  Evaluatable->False],
Cell[1853, 55, 100, 2, 26, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[1978, 61, 156, 4, 77, "Subtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2159, 69, 114, 2, 46, "Subsection",
  Evaluatable->False],
Cell[2276, 73, 2463, 85, 244, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[4776, 163, 98, 2, 30, "Subsection",
  Evaluatable->False],
Cell[4877, 167, 4157, 143, 222, "Text",
  Evaluatable->False],
Cell[9037, 312, 590, 20, 46, "Text",
  Evaluatable->False],
Cell[9630, 334, 1010, 36, 62, "Text",
  Evaluatable->False],
Cell[10643, 372, 590, 20, 46, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[11270, 397, 100, 2, 30, "Subsection",
  Evaluatable->False],
Cell[11373, 401, 2143, 66, 174, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

