(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     22577,        822]*)
(*NotebookOutlinePosition[     23667,        857]*)
(*  CellTagsIndexPosition[     23623,        853]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["7. Lists III:  Repetition with Lists"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision: January 26 1998", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In the previous section, we learned how to perform operations repeatedly \
on separate values.  In this section we learn how to perform operations \
repeatedly, using a value from the previous operation in the next:  this sort \
of repetition is called ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["repetition with feedback",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[".  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" operations/structures introduced: \n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["     Nest[]\n     NestList[]\n     Fold[]\n     FoldList[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Nest, Fold"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Nest, NestList"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "We have seen several functions which take another function as an argument, \
such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Map[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MapThread[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  These ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["higher-order functions",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ", or \"adverbs\", as well called them in the last section, are some of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox["'s most powerful functions.  We present two more, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is used to apply the same function repeatedly to a value, in the \
following way:  each time, the function is applied to the result of the \
previous application.  For instance, applying the squaring function three \
times in this way to the value 2, we would find the square of 2, namely, 4; \
its square, namely 16; and finally its square, namely 256.  The ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" takes the function to be applied as the first argument, the initial \
value as the second, and the number of repetitions of the function as the \
third.  Hence our squaring of 2 can be accomplished with the following \
command:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[square];
square[x_] := x^2;
Nest[square,2,3]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["NestList[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is similar to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" in that it takes as arguments a function, a starting value, and the \
number of times to \"iterate\" or \"nest\" the function, but \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["NestList[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" returns a list of all intermediate calculations, including the initial \
value.  We can see successive square roots of 10 as follows:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["NestList[Sqrt,10,4]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "If we want to see the decimals we can wrap this command inside \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["N[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", or we can just plug in a decimal to start with.   ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["NestList[Sqrt,10.0,4]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["NestList[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" are more elegant ways to achieve repetition---and certainly use fewer \
keystrokes---than performing the same operation over and over in separate \
commands:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Sqrt[10.0]", "Input",
  AspectRatioFixed->True],

Cell["Sqrt[%]", "Input",
  AspectRatioFixed->True],

Cell["Sqrt[%]", "Input",
  AspectRatioFixed->True],

Cell["Sqrt[%]", "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Fold, FoldList"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is similar to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", except that the function named in the first argument to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" must be one that requires two arguments, such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plus[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Times[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Subtract[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", or \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Divide[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", for example.  Since the function requires two arguments, we must \
examine how \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" will use the result from one application of the named function in \
applying the function again.  What happens is that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" takes the result of the previous application and uses it as the first \
argument in the next application, drawing the second argument in the next \
application from a list we provide \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  Each time, then, a new second argument is drawn from the list.  The \
only issue, then, is how \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" first begins; what will it use for the first argument of the first \
application?  The answer is that we must provide this first, initial value, \
separately.  Let's look at an example.  We will use \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plus",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for the function, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for the initial value, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{b,c,d,e}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for the list.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[a,b,c,d,e];
Fold[Plus,a,{b,c,d,e}]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" first computes \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plus[a,b]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", namely \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a+b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"; then \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plus[a+b,c]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", namely \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a+b+c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"; then \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plus[a+b+c,d]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", namely \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a+b+c+d",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"; and finally \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plus[a+b+c+d,e]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", namely \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a+b+c+d+e",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  Note in particular how all of the second arguments came from the list \
passed to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" as its third argument.  As one might expect, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["FoldList[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" returns a list of all intermediate calculations, including the initial \
value.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["FoldList[Plus,a,{b,c,d,e}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Let us examine another example, using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Times[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", the familiar multiplication operator.  Take a moment to guess what the \
output of the following would be.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["FoldList[Times,0,Range[10]]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Not too interesting; we'll find all of the intermediate products of \
0*1*2*...*10.  If we start with 1, however, we can find 10 factorial, or \
1*2*...*10:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["FoldList[Times,1,Range[2,10]]", "Input",
  AspectRatioFixed->True],

Cell["10!", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Repetition With and Without Feedback"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" are examples of what we call ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["repetition with feedback",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ".  To explain repetition with feedback, let us define instead what it is \
not:  repetition without feedback.  The function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Table[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is an example of an implementation of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["repetition without feedback",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[", which means that no iteration depends on the one before.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["sayHi := \"Hello\"", "Input",
  AspectRatioFixed->True],

Cell["Table[sayHi,{5}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["However, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" each use the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["result",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" of the previous iteration in the current one.  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" applies a function to the result of the previous iteration, while \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" applies a function to the result of the previous iteration and a new \
value taken from a list.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Example:  Powers of 2"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Let's examine two ways to compute successive powers of 2, using repetition \
with and without feedback.  One way is to determine, ahead of time, what \
exponents we need, and then use \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Map[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" to apply the appropriate function to each of these powers.  Suppose we \
want the first 10 powers of 2.  We use \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Range[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to find the first ten integers:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Range[10]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Then we can raise 2 \"to\" the entire list, i.e., we can raise 2 to each \
element of the list using a list operation, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["^",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["2 ^ Range[10]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["What ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" executed, however, was \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["2^1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["2^2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["2^3",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and so on, to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["2^10",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  We notice that each result is simply 2 times the previous result; ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " does not need to start with 2 and multiply many 2's each time.  A more \
efficient way to solve the problem, then, is to use repetition with feedback, \
as follows:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[times2];
times2[x_] := x*2;
NestList[times2,2,9]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Note that we used 9 iterations, not 10, since the initial value is placed in \
the list."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Reading Code"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "To test your comprehension of the material covered so far, try to \
determine the output of the following cells ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["without ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  "executing them on your machine.   Then execute the cells to check.  This \
exercise is a good skill to develop, for those who cannot predict the results \
of their code are performing more guessing than problem solving.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
midpoints[list_] := 
   (Drop[list,-1] + Drop[list,1]) / 2\
\>", "Input",
  AspectRatioFixed->True],

Cell["xs = Range[0,1,.2]", "Input",
  AspectRatioFixed->True],

Cell["NestList[midpoints,xs,5]", "Input",
  AspectRatioFixed->True],

Cell["%//TableForm", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowToolbars->{},
WindowSize->{520, 509},
WindowMargins->{{124, Automatic}, {Automatic, 1}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003809T?o>old</PW30fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400A7M;U0000000000060801T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 111, 2, 136, "Title",
  Evaluatable->False],
Cell[1853, 55, 99, 2, 26, "SmallText",
  Evaluatable->False],
Cell[1955, 59, 586, 17, 64, "Text",
  Evaluatable->False],
Cell[2544, 78, 441, 14, 82, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3010, 96, 87, 2, 50, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3122, 102, 94, 2, 46, "Subsection",
  Evaluatable->False],
Cell[3219, 106, 1425, 51, 82, "Text",
  Evaluatable->False],
Cell[4647, 159, 1263, 36, 128, "Text",
  Evaluatable->False],
Cell[5913, 197, 101, 5, 57, "Input"],
Cell[6017, 204, 956, 31, 78, "Text",
  Evaluatable->False],
Cell[6976, 237, 62, 1, 27, "Input"],
Cell[7041, 240, 430, 14, 46, "Text",
  Evaluatable->False],
Cell[7474, 256, 64, 1, 27, "Input"],
Cell[7541, 259, 658, 23, 62, "Text",
  Evaluatable->False],
Cell[8202, 284, 53, 1, 27, "Input"],
Cell[8258, 287, 50, 1, 27, "Input"],
Cell[8311, 290, 50, 1, 27, "Input"],
Cell[8364, 293, 50, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8451, 299, 94, 2, 46, "Subsection",
  Evaluatable->False],
Cell[8548, 303, 3467, 116, 190, "Text",
  Evaluatable->False],
Cell[12018, 421, 91, 4, 42, "Input"],
Cell[12112, 427, 2301, 84, 96, "Text",
  Evaluatable->False],
Cell[14416, 513, 69, 1, 27, "Input"],
Cell[14488, 516, 465, 15, 46, "Text",
  Evaluatable->False],
Cell[14956, 533, 70, 1, 27, "Input"],
Cell[15029, 536, 231, 5, 46, "Text",
  Evaluatable->False],
Cell[15263, 543, 72, 1, 27, "Input"],
Cell[15338, 546, 46, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[15433, 553, 113, 2, 30, "Section",
  Evaluatable->False],
Cell[15549, 557, 1294, 43, 82, "Text",
  Evaluatable->False],
Cell[16846, 602, 61, 1, 27, "Input"],
Cell[16910, 605, 59, 1, 27, "Input"],
Cell[16972, 608, 1246, 44, 64, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18243, 656, 101, 2, 46, "Subsection",
  Evaluatable->False],
Cell[18347, 660, 823, 25, 78, "Text",
  Evaluatable->False],
Cell[19173, 687, 52, 1, 27, "Input"],
Cell[19228, 690, 433, 15, 46, "Text",
  Evaluatable->False],
Cell[19664, 707, 56, 1, 27, "Input"],
Cell[19723, 710, 1456, 52, 82, "Text",
  Evaluatable->False],
Cell[21182, 764, 105, 5, 57, "Input"],
Cell[21290, 771, 163, 4, 30, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[21490, 780, 92, 2, 46, "Subsection",
  Evaluatable->False],
Cell[21585, 784, 648, 18, 80, "Text",
  Evaluatable->False],
Cell[22236, 804, 109, 4, 42, "Input"],
Cell[22348, 810, 61, 1, 27, "Input"],
Cell[22412, 813, 67, 1, 27, "Input"],
Cell[22482, 816, 55, 1, 27, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

