(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     25762,        931]*)
(*NotebookOutlinePosition[     26792,        964]*)
(*  CellTagsIndexPosition[     26748,        960]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["12. Structured Patterns"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision:  February 18 1998", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "While some programming languages allow functions which have parameters of \
complex types, few do so with as much generality as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ".  In this section we consider some of the extensive ways in which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows arguments to be recognized in patterns, as well as some examples \
of how useful such pattern recognition can be.  We also consider optional and \
default parameters."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" operations/structures introduced: \n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["     MatchQ[]\n     ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["parameter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["___\n     Count[]\n     RotateLeft[]\n     :",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["defaultValue",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Advanced Patterns"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Structured Patterns with Conditions"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"In the previous section we considered data type checking, boolean tests, \
conditions, and simple structured patterns, each of which is incorporated in \
the following example."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[below]
below[{x_Integer,y_?NumberQ} /; x>y]  :=
   \"The point is below y=x.\"\
\>", "Input",
  AspectRatioFixed->True],

Cell["below[{345234,23}]", "Input",
  AspectRatioFixed->True],

Cell["below[{1,12}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"With regard to conditions, it is important to realize that conditions can be \
applied only to a single preceding parameter, as in the example above, where \
the single parameter was a list with two entries.  Conditions cannot be \
successfully reference the values of any parameters before or after the \
immediately preceding parameter.  Thus, the following function does not \
perform correctly."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[below]
below[x_Integer,y_Integer /; x>y] :=
\t\t\t\"The point is below y=x.\"\
\>", "Input",
  AspectRatioFixed->True],

Cell["below[{345234,23}]", "Input",
  AspectRatioFixed->True],

Cell["below[{1,12}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"In this section we consider a new sort of pattern matching capability:  \
allowing a parameter to represent several values, and allowing a parameter to \
represent several or no values, depending on the input to the function.  We \
then consider examples of advanced patterns."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[
"Multipart Arguments (Two, Three Underscores, MatchQ)"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Recall that we defined a function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["switchTwo[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which switched the first two elements of a three-element list.  What \
if we wanted to define \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["switchTwo[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" similarly for a list of any number of elements greater than two? Here \
is a cumbersome solution:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[switchTwo];
switchTwo[list_List /; Length[list]>1 ] :=
\t\t\tJoin[{list[[2]],list[[1]]},Drop[list,{1,2}]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["switchTwo[{1,2,3,4,5,6}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Why cumbersome? It is so because the argument is followed by both a data \
type check and a condition, and the overall definition is much too long for \
such a simple operation.  Another solution might use a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Module",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  " and copy the list to another one, altering specific elements in the new \
list:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[switchTwo];
switchTwo[list_List /; Length[list]>1 ] :=
\tModule[{newlist},
\t\t  newlist = list;
\t\t  newlist[[2]]=list[[1]];
\t\t  newlist[[1]]=list[[2]];
\t\t  newlist
\t];\
\>", "Input",
  AspectRatioFixed->True],

Cell["switchTwo[{1,2,3,4,5,6}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Still, this is a long solution.  Instead, we use an appropriate pattern.  \
If two underscores are placed after a parameter name in a function \
definition, then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will allow more than one value to take its place in the argument passed \
to the function.  For instance, if we define the function as follows, the \
\"rest of the list\" beyond the first two elements will be left intact."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[switchTwo];
switchTwo[{a_, b_, c__}] := {b, a, c}\
\>", "Input",
  AspectRatioFixed->True],

Cell["switchTwo[{1,2,3,4,5,6}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Notice that the parameter \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was assigned the integer 1, the parameter \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" the integer 2, and the parameter \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sequence",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["3, 4, 5, 6",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  The catch here is that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is required to have some value; with our current condition, we cannot \
call \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["switchTwo[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" with only two parameters, because then \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" would be left without a value.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["switchTwo[{1,2}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "If we wish to permit the assignment of no values to the parameter \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", we append to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"three underscores; this syntax indicates to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" that the argument \"c\" can take no value, if necessary.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[switchTwo];
switchTwo[{a_, b_, c___}] := {b, a, c}\
\>", "Input",
  AspectRatioFixed->True],

Cell["switchTwo[{1,2,3,4,5,6}]", "Input",
  AspectRatioFixed->True],

Cell["switchTwo[{1,2}]", "Input",
  AspectRatioFixed->True],

Cell["switchTwo[{1}]", "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["MatchQ"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "It is not always obvious whether or not a certain actual parameter matches \
a pattern required for a function.  Using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MatchQ[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" helps us solve this dilemma:  it performs the pattern-matching for the \
first argument, given the pattern in the second, and returns a boolean value \
indicating whether or not the match was successful.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["MatchQ[1,t__]", "Input",
  AspectRatioFixed->True],

Cell["MatchQ[{1,2},{a_,b__,c___}]", "Input",
  AspectRatioFixed->True],

Cell["MatchQ[{1,2},{a_,b__,c__}]", "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Using Patterns"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["An Average Function"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Our goal here is to define a general-purpose average function.  We might \
begin by first defining a function that finds the average of a list."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[ave];
ave[x_] := N[ Apply[ Plus, x ] / Length[x] ]\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We must be prepared, however, for some bad input to give us problems.  For \
instance:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["ave[\"Hello\"]", "Input",
  AspectRatioFixed->True],

Cell["ave[1,2,3]", "Input",
  AspectRatioFixed->True],

Cell["ave[{1,2,3}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We therefore improve the function with our usual additions:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[ave];

ave::usage = \"ave[list] finds a numeric approximation to the average of the \
elements of the list\";

ave[x_List] := N[ Apply[ Plus, x ] / Length[x] ];

ave[x_] := 
   Print[\"Your argument \\\"\",x,\"\\\" is not a list.\"];\
\>", "Input",
  AspectRatioFixed->True],

Cell["ave[\"Hello\"]", "Input",
  AspectRatioFixed->True],

Cell["ave[1,2,3]", "Input",
  AspectRatioFixed->True],

Cell["ave[{1,2,3}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Looking at the action of our function, we notice that we might want \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ave[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" to average a sequence of numbers, as in the second case above, even if \
the numbers are not initially in the form of a list.  We can define \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ave[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" to take a list of more than one argument and enclose it in a list, as \
follows:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[ave];

ave::usage = \"ave[list] finds an real number approximation to the average of \
the elements of the list\";

ave[x_List] := N[ Apply[ Plus, x ] / Length[x] ];

ave[x___] := ave[{x}];

ave[x_] := 
   Print[\"Your argument \\\"\",x,\"\\\" is not a list.\"]\
\>", "Input",
  AspectRatioFixed->True],

Cell["ave[\"Hello\"]", "Input",
  AspectRatioFixed->True],

Cell["ave[1,2,3]", "Input",
  AspectRatioFixed->True],

Cell["ave[{1,2,3}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Now we have a function which can average several arguments.  What happened \
with \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Hello",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", though?   It matched \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x___",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and not \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x_List",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", so \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ave[\"Hello\"]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" became \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ave[{\"Hello\"}]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and then it was averaged!  Note that the definition \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ave[x_] := ...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" never executes, since all arguments will be encapsulated in a list or \
be a list already.  Here is a better solution:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[ave];

ave::usage = \"ave[list] finds an real number approximation to the average of \
the elements of the list\";

ave[x_List] := N[ Apply[ Plus, x ] / Length[x] ];

ave[x___?NumberQ] := ave[{x}];

ave[x_] := Print[\"Your argument \\\"\",x,\"\\\" is not a list.\"];\
\>", 
  "Input",
  AspectRatioFixed->True],

Cell["ave[\"Hello\"]", "Input",
  AspectRatioFixed->True],

Cell["ave[1,2,3]", "Input",
  AspectRatioFixed->True],

Cell["ave[{1,2,3}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Further improvements are certainly possible:  we have not yet prevented \
the user from explicitly giving \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ave[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" a list of non-numeric values.  Consider how we might improve the \
function to enforce that constraint.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData["Counting Random Numbers (Count)"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["In this example we make use of the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Count[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which determines how many elements of a list satisfy a certain \
condition.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["?Count", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The pattern in the second parameter need not include underscores, data \
types, or boolean tests; we are permitted to ask for exact matches, by \
setting the second parameter to the expression we wish matched exactly.  This \
behavior is analogous to defining a function with parameters without \
underscores, such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["f[x]=3",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\":  in this case, only when the parameter is exactly \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" will the definition be used.  We might want to know how many zeros \
appear in a given list.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Count[{1,2,3,0,2,0,4},0]", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We might instead ask how many numeric approximations occur in a given \
list."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Count[{1.2, 1, 3.7, dog }, _Real ]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note here that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["_Real",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is a legitimate pattern; we have not included a parameter name, for we \
do not have a need to reference the value being tested.  In the following \
example, in which we use a data type check and a condition to test both \
whether the value is a numeric approximation and whether it is less than 3, \
we need to refer to the value, so we give it a name:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Count[{1.2, 1, 3.7, dog }, x_Real /; x<3 ]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Count[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", we can now simulate coin tosses, asking how many of 100 random \
numbers, chosen from 0 to 1, are less than 0.5.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Count[ Table[ Random[],{100}], x_ /; x<.5]", "Input",
  AspectRatioFixed->True]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Default Arguments"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "A default argument is a parameter which, if not specified, is assigned \
some particular default value.  In the function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["N[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", for instance, the second parameter is optional, and if it is not \
specified, the number of digits for the approximation is determined \
internally by ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[".  Another example is provided by the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["RotateLeft[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" function.  This function rotates the list given in the first argument \
left by the number of positions given in the second argument.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["?RotateLeft", "Input",
  AspectRatioFixed->True],

Cell[TextData[
"But note that if we omit the second argument, the list will be rotated by \
one position.  The second argument is thus assigned the \"default value\" 1; \
if that argument is left out, then \"1\" is the value it will take.  "], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In order to specify a default parameter inside a function definition, we \
place a colon (\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[":",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\") followed by the default value after the parameter specification, \
before the next comma, if applicable.  As an example, suppose we want a \
function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["addOnes[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" which prepends and appends as many 1s as are indicated by the second \
argument to the list indicated by the first argument.  We might define \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["addOnes[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" as follows:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
Clear[addOnes];
addOnes[l_List,i_Integer:1]:=
\tNest[(Prepend[Append[#,1],1])&,l,i];\
\>", "Input",
  AspectRatioFixed->True],

Cell["addOnes[{2,2},5]", "Input",
  AspectRatioFixed->True],

Cell["addOnes[{2,2}]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "It is true that there is an alternate method of specifying the same \
function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["addOnes[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\"; we could write that if there are two arguments, it should have the \
definition above, while if it has only one argument, it should have an \
alternate definition, using 1 instead of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
addOnes[l_List,i_Integer]:=
\tNest[(Prepend[Append[#,1],1])&,l,i];
addOnes[l_List]:=
\tNest[(Prepend[Append[#,1],1])&,l,1];\t\t\
\>", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "Notice that this method eliminates the default argument.  This method is \
less attractive, however, because, first, a reader must look closely at each \
function to notice that the functions are basically the same, and, second, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is required to store two complicated definitions instead of one, wasting \
memory."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Finally, we should say that we have not covered all of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  "'s great generality in specifying patterns.  Consult the Help Browser, or \
see Stephen Wolfram's ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic",
    FontVariations->{"Underline"->True}],
  StyleBox[", section 2.3, for more information.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
WindowSize->{520, 509},
WindowMargins->{{84, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?mooh<<H`Ui0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 98, 2, 98, "Title",
  Evaluatable->False],
Cell[1832, 55, 101, 2, 26, "SmallText",
  Evaluatable->False],
Cell[1936, 59, 565, 13, 98, "Text",
  Evaluatable->False],
Cell[2504, 74, 803, 28, 96, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3332, 106, 94, 2, 50, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3451, 112, 115, 2, 46, "Subsection",
  Evaluatable->False],
Cell[3569, 116, 251, 5, 46, "Text",
  Evaluatable->False],
Cell[3823, 123, 135, 5, 57, "Input"],
Cell[3961, 130, 61, 1, 27, "Input"],
Cell[4025, 133, 56, 1, 27, "Input"],
Cell[4084, 136, 473, 8, 94, "Text",
  Evaluatable->False],
Cell[4560, 146, 134, 5, 57, "Input"],
Cell[4697, 153, 61, 1, 27, "Input"],
Cell[4761, 156, 56, 1, 27, "Input"],
Cell[4820, 159, 351, 6, 62, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[5208, 170, 133, 3, 46, "Subsection",
  Evaluatable->False],
Cell[5344, 175, 732, 24, 64, "Text",
  Evaluatable->False],
Cell[6079, 201, 162, 5, 72, "Input"],
Cell[6244, 208, 67, 1, 27, "Input"],
Cell[6314, 211, 605, 18, 79, "Text",
  Evaluatable->False],
Cell[6922, 231, 232, 10, 132, "Input"],
Cell[7157, 243, 67, 1, 27, "Input"],
Cell[7227, 246, 522, 11, 80, "Text",
  Evaluatable->False],
Cell[7752, 259, 106, 4, 42, "Input"],
Cell[7861, 265, 67, 1, 27, "Input"],
Cell[7931, 268, 1793, 64, 83, "Text",
  Evaluatable->False],
Cell[9727, 334, 59, 1, 27, "Input"],
Cell[9789, 337, 835, 28, 65, "Text",
  Evaluatable->False],
Cell[10627, 367, 107, 4, 42, "Input"],
Cell[10737, 373, 67, 1, 27, "Input"],
Cell[10807, 376, 59, 1, 27, "Input"],
Cell[10869, 379, 57, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[10951, 384, 89, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[11043, 388, 648, 18, 79, "Text",
  Evaluatable->False],
Cell[11694, 408, 56, 1, 27, "Input"],
Cell[11753, 411, 70, 1, 27, "Input"],
Cell[11826, 414, 69, 1, 27, "Input"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11956, 422, 91, 2, 30, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12072, 428, 99, 2, 46, "Subsection",
  Evaluatable->False],
Cell[12174, 432, 220, 5, 46, "Text",
  Evaluatable->False],
Cell[12397, 439, 107, 4, 42, "Input"],
Cell[12507, 445, 161, 4, 30, "Text",
  Evaluatable->False],
Cell[12671, 451, 57, 1, 27, "Input"],
Cell[12731, 454, 53, 1, 27, "Input"],
Cell[12787, 457, 55, 1, 27, "Input"],
Cell[12845, 460, 134, 3, 30, "Text",
  Evaluatable->False],
Cell[12982, 465, 290, 11, 162, "Input"],
Cell[13275, 478, 57, 1, 27, "Input"],
Cell[13335, 481, 53, 1, 27, "Input"],
Cell[13391, 484, 55, 1, 27, "Input"],
Cell[13449, 487, 786, 25, 80, "Text",
  Evaluatable->False],
Cell[14238, 514, 318, 13, 192, "Input"],
Cell[14559, 529, 57, 1, 27, "Input"],
Cell[14619, 532, 53, 1, 27, "Input"],
Cell[14675, 535, 55, 1, 27, "Input"],
Cell[14733, 538, 1509, 52, 98, "Text",
  Evaluatable->False],
Cell[16245, 592, 326, 13, 192, "Input"],
Cell[16574, 607, 57, 1, 27, "Input"],
Cell[16634, 610, 53, 1, 27, "Input"],
Cell[16690, 613, 55, 1, 27, "Input"],
Cell[16748, 616, 530, 17, 63, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[17315, 638, 111, 2, 46, "Subsection",
  Evaluatable->False],
Cell[17429, 642, 613, 22, 48, "Text",
  Evaluatable->False],
Cell[18045, 666, 49, 1, 27, "Input"],
Cell[18097, 669, 952, 27, 95, "Text",
  Evaluatable->False],
Cell[19052, 698, 67, 1, 27, "Input"],
Cell[19122, 701, 152, 4, 30, "Text",
  Evaluatable->False],
Cell[19277, 707, 77, 1, 27, "Input"],
Cell[19357, 710, 686, 18, 79, "Text",
  Evaluatable->False],
Cell[20046, 730, 85, 1, 27, "Input"],
Cell[20134, 733, 439, 15, 47, "Text",
  Evaluatable->False],
Cell[20576, 750, 85, 1, 27, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20710, 757, 94, 2, 30, "Section",
  Evaluatable->False],
Cell[20807, 761, 1118, 34, 98, "Text",
  Evaluatable->False],
Cell[21928, 797, 54, 1, 27, "Input"],
Cell[21985, 800, 302, 6, 62, "Text",
  Evaluatable->False],
Cell[22290, 808, 1068, 34, 97, "Text",
  Evaluatable->False],
Cell[23361, 844, 135, 5, 57, "Input"],
Cell[23499, 851, 59, 1, 27, "Input"],
Cell[23561, 854, 57, 1, 27, "Input"],
Cell[23621, 857, 757, 25, 64, "Text",
  Evaluatable->False],
Cell[24381, 884, 178, 6, 72, "Input"],
Cell[24562, 892, 450, 10, 80, "Text",
  Evaluatable->False],
Cell[25015, 904, 719, 23, 66, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

