(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     29620,       1003]*)
(*NotebookOutlinePosition[     30706,       1038]*)
(*  CellTagsIndexPosition[     30662,       1034]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["17. Recursion II:  Dynamic Programming"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision:  February 8 1999", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"In this section we continue our study of recursion, presenting two more \
examples, and discussing the relationships between recursion and dynamic \
programming, a method which may increase the speed of our program at the \
expense of using additional space."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" operations/structures introduced: \n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["     ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["recursive definitions",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["\n     GCD[]\n     Mod[]\n     Quotient[]\n     Trace[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"Another Recursive Example:  The Euclidean Algorithm"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Recall that the greatest common divisor of two integers \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is the largest (positive) integer which divides each evenly (with \
remainder 0).  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " gives us a way to compute greatest common divisors (GCD's), the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GCD[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" command.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["GCD[72,30]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " also provides a remainder function which divides the first parameter by \
the second and returns the remainder:  the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mod[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" function.  (The \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mod[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" function is useful in determining whether one integer is divisible by \
another.  For example, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mod[a,3]==0",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" tests whether or not \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is evenly divisible by 3.)",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Mod[72,30]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "And, for completeness, we also have the integer quotient function, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Quotient[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which provides the quotient, which is the number of times the first \
parameter divides the second, ignoring the remainder.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Quotient[72,30]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The purpose of this section is to use recursion to program our own GCD \
function."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"A famous theorem from arithmetic implies recursion"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["A famous mathematical theorem states that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GCD[a,b]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" equals ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GCD[b,r]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", where ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["r",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" is ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mod[a,b]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ".  What is interesting about the theorem from a recursive standpoint is \
that it provides a way to \"simplify\" the two parameters, so that the \
function can be invoked again.  How?  First, notice that the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mod[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" function returns a remainder, an integer between 0 and the value of the \
second argument.  Now suppose that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is less than \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Then \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b,r",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", the new pair, is a pair of integers both less than or equal to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", so that the maximum of the pair has decreased, from \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Suppose, on the other hand, that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is less than \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Then the new pair \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b,r",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is equal to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b,a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", from \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a=Mod[a,b]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is greater than \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  However, now the pair has the first element greater than the second \
element, so that the first case applies, and the next pair will have a \
smaller maximum value.  Finally, suppose that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" equals \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Then the next pair is \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b,0",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", and we know that the GCD of any number and 0 is the number itself, \
which is in this case \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  Putting these facts together, we see that repeatedly applying the \
rule \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GCD[a,b]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" equals ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GCD[b,Mod[a,b]]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" reduces the maximum value of the pair of parameters to GCD.  Since the \
two parameters are always nonnegative integers, at some point we much reach a \
scenario in which one parameter is zero, and the GCD at that point is easily \
found.  In other words, we have not only a way to simplify parameters in \
order to invoke the GCD function again, but a base case:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GCD[b,0]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" equals ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for any nonnegative integer \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  As an example, consider the following sequence of parameter \
replacements:  GCD[15,6] = GCD[6,3] = GCD[3,0] = 3.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Now we are in a position to write a recursive GCD function:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
recurGCD[a_Integer?Positive, 0] := a
recurGCD[a_Integer?Positive, b_Integer?Positive] := 
   recurGCD[b, Mod[a,b]]\
\>", "Input",
  AspectRatioFixed->True],

Cell["recurGCD[15,6]", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Recall that the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Trace[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" command can be useful with recursive functions, and that executing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Trace[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" with the name of a function as the second argument causes \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Trace[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to announce only each call of the function.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Trace[recurGCD[15,6],recurGCD]", "Input",
  AspectRatioFixed->True],

Cell["recurGCD[72,30]", "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dynamic Programming; Making Recursion Run Faster"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Fibonacci numbers begin as 1,1, and then continue as the sum of the \
preceding two numbers:  2, 3, 5, 8, 13, 21, 34, and so on.  A simple \
recursive implementation of a Fibonacci number-finder would be the \
following:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib]\nfib[0]=1;\nfib[1]=1;\nfib[n_]:=fib[n-1]+fib[n-2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We can find the 7th Fibonacci number, then by executing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["fib[6]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "There are some important time issues to be considered with recursive \
programs of this sort.  To highlight these, let's ask \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Trace[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to tell us how many function calls to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" it makes when it considers \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["fibUse = Trace[fib[6],fib[_Integer]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Sort[Flatten[fibUse]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We see that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[5]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" are each computed once, that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[4]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is computed twice, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[3]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" three times, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[2]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" five times, and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[1]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" eight times.   A lot of work goes into repeatedly computing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[4]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\"!  There is an obvious improvement here:  we should save the value of \
\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[n]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" once we find it. We can do this by modifying our current definition \
only slightly, in the next input cell.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The change is so small it might be hard to see.  In the last line of the \
cell below we are not only computing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[n]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" but are also setting up a special case of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[n]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", as follows.  By using an assignment statement (\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[n]=",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["...\"), we are instructing ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" that whenever \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[n]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is executed with the same value again, it should use the value we've \
specified instead of using the recursive definition of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  It will be just as if we had specified the special value as we did \
with \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[0]=1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\". ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib2]\nfib2[0]=1;\nfib2[1]=1;\nfib2[n_]:= fib2[n] = \
fib2[n-1]+fib2[n-2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["For example, when we execute \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is computed and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is set equal to the computed value, and the next time we request the \
value of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2[6]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", the value is not recomputed using recursion, but instead is simply \
looked up.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["fib2[6]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["?fib2"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Now let's return to the time issue.  We'll clear each of the two variants of \
our Fibonacci-number function, redefine them, and time how long it takes to \
compute the 20th Fibonacci number each way."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib]\nfib[0]=1;\nfib[1]=1;\nfib[n_]:=fib[n-1]+fib[n-2]\n\nClear[fib2]\n\
fib2[0]=1;\nfib2[1]=1;\nfib2[n_]:= fib2[n] = fib2[n-1]+fib2[n-2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Timing[fib[20]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Timing[fib2[20]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Fairly dramatic.  Even more dramatic are the next calls:"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Timing[fib[20]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Timing[fib2[20]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Wow.  Take a look at what ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" is storing for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["??fib2"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "What if we try another option: a tail recursive Fibonacci function, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib3",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["?",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib3]\nfib3[\n  n_Integer?((#>=0)&), \n  n0_Integer:1, \n  \
n1_Integer:1\n]:= \n  Which[\n    n == 0, n0,\n    n == 1, n1,\n    True,   \
fib3[n-1, n1, n0+n1]\n  ]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Map[fib3, Range[0, 10]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Timing[fib3[20]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Hmmm, that's pretty fast too.  Take a look at what ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" is storing for ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib3",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["??fib3"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Dynamic Programming for the Euclidean Algorithm?"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["\<\
The section above provided us a first look at using dynamic \
programming to solve a programming problem, which is a method whereby the \
program (a) saves certain results for recall as they are computed, but (b) \
does not simply compute all of the possible results ahead of time.  Dynamic \
programming is a compromise between two extremes, one in which, say, the \
first 1000 Fibonacci numbers are computed ahead of time and then are looked \
up when requested, the other in which no values are saved as they are \
computed but are always recomputed when requested.  In the first extreme, we \
find a large use of time at the beginning of the program, in order to compute \
all of the possible values first, and a large use of space (in the computer's \
memory) to store all of the possible results.  At the other extreme, we find \
a small space burden but a probable chance that time will be wasted by \
recomputing results already computed before. Dynamic programming uses time \
judiciously, using memory as needed to store requested results for later, but \
not (pre-)computing any results which we may not ever need.\
\>", "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Is dynamic programming an appropriate method for implementing the \
Euclidean Algorithm?  In other words, would implementing such a method \
balance time and space constraints?  We first realize that under special \
circumstances the choice may be clear.  For instance, if the computer in \
question has very little memory or if we are entirely satisfied with the \
amount of time the computer takes to compute the GCD of any two numbers we \
might be interested in, we would not want to use dynamic programming.  Can we \
answer the question more generally, however?  The difference between our \
recursive code for the Euclidean Algorithm and our recursive code for \
Fibonacci numbers lies in the fact that the definition of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[n]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" forces the computation (or recall) of every \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[x]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for integers ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x < n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", while \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "recurGCD",
  StyleBox["[a,b]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" forces the computation (or recall) of only certain values of the \
parameters of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  "recurGCD",
  StyleBox["[]\".  Put another way, computing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[15]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" will always benefit from knowing the values which \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[8]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was forced to compute, while computing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["recurGCD", "Input",
    FontWeight->"Plain"],
  StyleBox["[10,15]", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Plain"],
  StyleBox[
  "\" does not use any of the values found during the computation of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["recurGCD", "Input",
    FontWeight->"Plain"],
  StyleBox["[8,16]", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Plain"],
  StyleBox[
  "\".  We might conclude, roughly, that if we will be computing many, many \
GCDs of integers whose values fall in a relatively small range (say 1 to \
1000), using dynamic programming would prove a good idea, since we would need \
to store at most 1000 * 1000 = 1,000,000 integers, taking up 1 megabyte or \
less, and the frequency of the computations would insure that at some point \
the algorithm would begin recalling, instead of computing, values of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["recurGCD", "Input",
    FontWeight->"Plain"],
  StyleBox["[]", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Plain"],
  StyleBox[
  "\".  If the range of the parameters is very large, or if we will be \
computing relatively few instances of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["recurGCD", "Input",
    FontWeight->"Plain"],
  StyleBox["[]", "Input",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontWeight->"Plain"],
  StyleBox[
  "\", then dynamic programming may have very little benefit, either forcing \
us to set aside a large amount of memory, as in the first case, or storing \
values which may never be recalled again, as in the second case.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
WindowSize->{520, 509},
WindowMargins->{{108, Automatic}, {30, Automatic}},
PrintingCopies->1,
PrintingPageRange->{3, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003809T?o>old</PW30fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@CYh^0000000000060H01T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 113, 2, 136, "Title",
  Evaluatable->False],
Cell[1847, 55, 100, 2, 26, "SmallText",
  Evaluatable->False],
Cell[1950, 59, 333, 6, 62, "Text",
  Evaluatable->False],
Cell[2286, 67, 679, 23, 96, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2990, 94, 129, 3, 50, "Section",
  Evaluatable->False],
Cell[3122, 99, 1047, 37, 66, "Text",
  Evaluatable->False],
Cell[4172, 138, 63, 1, 27, "Input"],
Cell[4238, 141, 1222, 42, 83, "Text",
  Evaluatable->False],
Cell[5463, 185, 63, 1, 27, "Input"],
Cell[5529, 188, 519, 16, 63, "Text",
  Evaluatable->False],
Cell[6051, 206, 68, 1, 27, "Input"],
Cell[6122, 209, 157, 4, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6304, 217, 131, 3, 46, "Subsection",
  Evaluatable->False],
Cell[6438, 222, 6308, 215, 331, "Text",
  Evaluatable->False],
Cell[12749, 439, 134, 3, 30, "Text",
  Evaluatable->False],
Cell[12886, 444, 165, 5, 57, "Input"],
Cell[13054, 451, 57, 1, 27, "Input"],
Cell[13114, 454, 854, 28, 64, "Text",
  Evaluatable->False],
Cell[13971, 484, 73, 1, 27, "Input"],
Cell[14047, 487, 58, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[14154, 494, 125, 2, 30, "Section",
  Evaluatable->False],
Cell[14282, 498, 295, 6, 62, "Text",
  Evaluatable->False],
Cell[14580, 506, 114, 2, 72, "Input"],
Cell[14697, 510, 372, 13, 31, "Text",
  Evaluatable->False],
Cell[15072, 525, 59, 1, 27, "Input"],
Cell[15134, 528, 857, 29, 64, "Text",
  Evaluatable->False],
Cell[15994, 559, 89, 1, 27, "Input"],
Cell[16086, 562, 74, 1, 27, "Input"],
Cell[16163, 565, 1877, 67, 98, "Text",
  Evaluatable->False],
Cell[18043, 634, 1819, 61, 116, "Text",
  Evaluatable->False],
Cell[19865, 697, 133, 3, 72, "Input"],
Cell[20001, 702, 1056, 38, 64, "Text",
  Evaluatable->False],
Cell[21060, 742, 60, 1, 27, "Input"],
Cell[21123, 745, 58, 1, 27, "Input"],
Cell[21184, 748, 275, 5, 62, "Text",
  Evaluatable->False],
Cell[21462, 755, 197, 3, 147, "Input"],
Cell[21662, 760, 68, 1, 27, "Input"],
Cell[21733, 763, 69, 1, 27, "Input"],
Cell[21805, 766, 131, 3, 30, "Text",
  Evaluatable->False],
Cell[21939, 771, 68, 1, 27, "Input"],
Cell[22010, 774, 69, 1, 27, "Input"],
Cell[22082, 777, 524, 20, 32, "Text",
  Evaluatable->False],
Cell[22609, 799, 59, 1, 27, "Input"],
Cell[22671, 802, 381, 14, 31, "Text",
  Evaluatable->False],
Cell[23055, 818, 224, 4, 177, "Input"],
Cell[23282, 824, 76, 1, 27, "Input"],
Cell[23361, 827, 69, 1, 27, "Input"],
Cell[23433, 830, 549, 20, 32, "Text",
  Evaluatable->False],
Cell[23985, 852, 59, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24081, 858, 125, 2, 30, "Section",
  Evaluatable->False],
Cell[24209, 862, 1197, 18, 222, "Text",
  Evaluatable->False],
Cell[25409, 882, 4183, 117, 374, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

