(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     42331,       1486]*)
(*NotebookOutlinePosition[     43362,       1519]*)
(*  CellTagsIndexPosition[     43318,       1515]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["19. Iterative Loops II:  Do, For"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision:  March 19 1998", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In this section we continue our consideration of iterative loops, \
introducing the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" variants of the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" loop.  These variants provide structured ways to accomplish common \
looping operations.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" operations/structures introduced: \n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["     Do[]\n     For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Examples of Basic Looping Techniques"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We first present two more examples of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" loops and discuss each of them.   It is especially important in the \
loops below to understand what variables are updated with every iteration of \
the loop and the way in which this updated variable affects the operation of \
the boolean test which controls exit from the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" loop.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Harmonic series"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["In theory, the sum of the Harmonic Series ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/1 + 1/2 + 1/3 + 1/4 + ...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  " grows arbitrarily large.  (This is not as obvious as you might think \
since ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/1^2 + 1/2^2 + 1/3^2 + 1/4^2 + ...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" sums to a finite number!)  Below we consider a function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["whenSumBeat[goal]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" that counts how many terms of the harmonic series are necessary for the \
series to surpass a given number.  In other words, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["whenSumBeat[goal]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" will return the first \"n\" such that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/1 + 1/2 + 1/3 + ... + 1/n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  is greater than \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["goal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[whenSumBeat]\nwhenSumBeat[goal_?NumberQ] := Module[ {sum, n},\n   sum \
= 0;\n   n = 0;\n   While[ sum <= goal,\n      n++;\n      sum = sum + 1/n\n  \
 ];\n   n\n]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["whenSumBeat[5]"], "Input",
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["whenSumBeat[8]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"! Don't try anything higher than 8, unless you have lots of patience."], 
  "Message",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  StyleBox[
  "Notice that two variables are initialized before the loop begins.  One, \
\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", is initialized to zero and will hold the value of the sums we will be \
computing, namely, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/1 + 1/2 + ...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".  The other, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", is initialized to zero and will represent the denominator of the term \
we will add to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  The variable \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is initialized to zero because the first command of the loop is to \
increment the value of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" before adding \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"; thus \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" must begin at zero so that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is the first fraction added to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  Also take note of the fact that this loop must execute two commands, \
one to increment \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", the other to add \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  While \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" holds the value in which we are ultimately interested, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" must be continually computed so that we can have an appropriate boolean \
test to control execution of the loop.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Powers of 2"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Here we consider a similar function, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["whenPowBeat[goal]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", which will return the first nonnegative value of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" such that",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[" 2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontVariations->{"CompatibilityType"->"Superscript"}],
  StyleBox[" > ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["goal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  We could solve this problem with logarithms or by using the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["^",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  " operation.  We do neither; instead, we will accumulate a product by \
multiplying by 2 each time through the loop until the product exceeds the \
goal.  The answer will be a count of how many times the loop body was \
executed.  (In the previous example, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was the loop counter.)",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[whenPowBeat]\nwhenPowBeat[goal_?NumberQ] := \n  Module[ {product, \
counter},\n    product = 1;\n    counter = 0;\n    While[ product <= goal,\n  \
    counter++;\n      product*=2\n    ];\n    counter\n  ]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Notice that two variables are initialized before the loop begins.  One, \
\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", is initialized to one and will hold the value of the products we will \
be computing, namely, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["2*2*2*...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".  The other, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", is initialized to zero and will represent the number of 2's we have \
placed in the product.  The variable \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is initialized to zero because the loop counts how many 2's are already \
in the product, and, at the beginning, the product contains no 2's.  Also \
take note of the fact that this loop must execute two commands, one to \
increment \"counter\", the other to multiply \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" by 2.  While \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" holds the value in which we are ultimately interested, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" must be continually computed so that we can have an appropriate boolean \
test to control execution of the loop.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "In general, deciding how to initialize the variables which are updated in \
a loop can be a tricky matter.  One way to help determine whether or not the \
initializations may be correct is to consider the cases in which the loop \
does not execute (in which case the boolean test returns ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["False",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  " on its first evaluation) and in which the loop executes exactly once.  In \
our case above, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" should remain 0 if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["goal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is less than 1, for we will need no 2's at all.  Similarly, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" should stop at 1 if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["goal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is between 1 and 2, for we will need exactly one 2 in \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  We check these to cases in the following commands:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["whenPowBeat[.5]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["whenPowBeat[1.5]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Since these work, we have some confidence that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" are initialized correctly.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["whenPowBeat[10000]"], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Do"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "When we do not know how many times a function or an operation should be \
performed, the strategy of using list-based functions to accomplish the task \
may not be appropriate, since most such functions operate only on entire \
lists.  Instead, we should employ recursion, or a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" loop.  When we do know how many times an operation should be performed, \
however, we could use the old list-based functions such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Table[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fold[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  However, these operations can be inefficient at times, as we saw in \
the previous section, and, moreover, many languages do not have analogues of \
such operations.  Typically other languages do have companions to the \
standard \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" construct, called the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" constructs, which provide ways to iterate a process a fixed number of \
times. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The syntax for a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" construct is simple: the first argument is a sequence of statements \
(separated by semicolons); the second argument is an iterator.  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" constructs are very similar, then, to instances of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Table[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  We use and compare both in the following examples.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Finding the sum of squares of even numbers"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Here we try to find the sum of the squares of the even numbers between 1000 \
and 2000."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["List-based solution"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Apply[Plus,Table[i^2,{i,1000,2000,2}]]"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Do loop solution"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Module[ {sum,i},\n   sum = 0;\n   Do[sum = sum + i^2, {i,1000,2000,2}];\n   \
sum\n]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" constructs have no return value, so we must still execute \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "-loop solution above in order to write out the value.  Is there any \
advantage to the iterative solution?  Yes: using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Table[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" at least temporarily tied up the computer's memory with a list of 501 \
integers, while the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" loop kept only one integer in memory, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" (in addition to the control variable \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\"), during its execution.  On a 386 PC computer, when one runs the list \
solution with 2000 changed to 2 million, the computer starts frantically \
flashing the hard-disk light as it tries to find room to record all of the \
list.  The ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  " loop solution, on the other hand, does not cause any memory problems, \
although it does take an equally long time.  (While other computers may be \
faster and have more memory, there will be a number large enough to cause the \
memory problems with the list-based solution!)",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["In defense of list-based thinking, however, we point out that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" does provide the function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Sum[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"; here is the best ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" solution.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Sum[i^2,{i,1000,2000,2}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["One could consider the functions \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Nest[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["FixedPoint[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Sum[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Product[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" in the category of list-based programming, but actually they are not \
manipulating lists!  They are special cases of iteration loops that are built \
into the language.  Thus, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Sum[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is really a basic ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" loop in disguise.  We have errantly called \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Sum[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" a list-based function because we have considered it as a single \
operation.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Fibonacci numbers with Do"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Read the following function and decipher its action."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib];\nfib[n_Integer?Positive] := Module[{oldfib,newfib,newestfib},\n  \
 oldfib = 1;\n   newfib = 1;\n   newestfib = 2;\n   Do[\n      oldfib = \
newfib;\n      newfib = newestfib;\n      newestfib = oldfib + newfib\n   \
,{n-3}];\n   If[n<=2, 1, newestfib]\n]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Map[fib,Range[5]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["fib[300]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["This function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["fib[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is much more efficient than a recursive version which does not \
implement dynamic programming. This solution is similar to a recursive \
version which does employ dynamic programming, but it is slightly faster \
since it does not need to keep track of many function calls, remembering \
parameters and return values from many executions of the same function over \
and over again.  The loop simply keeps track of three integers.  Let's time \
the various versions to convince ourselves.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Timing[fib[26]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib2]\nfib2[1]=1;\nfib2[2]=1;\nfib2[n_]:=fib2[n-1]+fib2[n-2];\n\
Timing[fib2[26]]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib3]\nfib3[1]=1;\nfib3[2]=1;\nfib3[n_]:= fib3[n] = \
fib3[n-1]+fib3[n-2];\nTiming[fib3[26]]"], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["For"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["A \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" construct encapsulates in one structure the idea of a loop in which (a) \
initialization occurs before the loop begins; (b) an operation, usually that \
of incrementing a variable, occurs at the end of every iteration; and (c) the \
loop stops when a certain boolean function returns ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["False",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".  Thus, a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" loop combines the versatility of a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" construct (with the boolean test) with a distinguished place to write \
the instructions for the end-of-iteration operation.  Many languages support \
an analogue of the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" construct.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The syntax of a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" construct is as follows.  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" takes four arguments, separated by commas as usual, and each argument \
can be a list of expressions separated by semicolons.  The first argument \
contains code which will be executed before the loop starts (the \
initialization);  the second contains the boolean test, which will be tested \
before each iteration begins and which controls whether or not the loop will \
continue executing; the third, the update operation (usually incrementing a \
test variable); and the fourth, the actual body of the loop.  We'll consider \
the above examples written with a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" construct instead.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Harmonic series"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[whenSumBeat]\nwhenSumBeat[goal_?NumberQ] := Module[ {sum, n},\n   \
For[sum=0; n=0, sum<=goal, n++, sum+=1/n];\n   n-1\n]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Initialization:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is set to 0, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to 1 (why is \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" initialized differently than it is in the previous version, and why is \
\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n-1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" returned instead of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"?).\nBoolean test:  we wish to iterate if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum<=goal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" before the iteration.\nEnd-of-iteration operation:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n++",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" increments \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" by ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".\nBody:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" has \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1/n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" added to it.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Powers of 2"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[whenPowBeat]\nwhenPowBeat[goal_?NumberQ] := \n  Module[ {product, \
counter},\n\t\t\t\tFor[ product=1; counter=0, product<=goal,     \n\t\t\t\t\t\
\t\t\t\tproduct*=2, counter++];\n    counter\n  ]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Initialization:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is set to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to 0.\nBoolean test:  we wish to iterate if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product<=goal",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" before the iteration.\nEnd-of-iteration operation:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["product",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is doubled.\nBody:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["counter",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is incremented by ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Finding the sum of squares of even numbers"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Module[ {sum,i},\n   For[sum=0; i=1000, i<=2000, i+=2, sum+=i^2];\n   sum\n\
]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Initialization:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is set to 0, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to 1000.\nBoolean test:  we wish to iterate if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i<=2000",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" before the iteration.\nEnd-of-iteration operation:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i+=2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" increments \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" by 2.\nBody:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["sum",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" has \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i^2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" added to it.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Fibonacci numbers with For"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fib];\nfib[n_Integer?Positive] := Module[{oldfib,newfib,newestfib,i},\n\
  For[oldfib=newfib=newestfib=i=1,\n  \t\t\ti<=n-2, i++,\n  \t\t\toldfib = \
newfib;\n  \t\t\tnewfib = newestfib;\n  \t\t\tnewestfib = oldfib + newfib];\n \
 newestfib\n]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Initialization:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["oldfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["newfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["newestfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" are all set to ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".\nBoolean test:  we wish to iterate if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i<=(n-2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" before the iteration would start.\nEnd-of-iteration operation:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i++",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" increments \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["i",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" by ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[".\nBody:  \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["oldfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" becomes what \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["newfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was; \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["newfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" becomes what \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["newestfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was, and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["newestfib",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" becomes the sum of those two quantities.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Notes"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Note that the end-of-iteration operation can always be omitted from its \
proper place and simply placed at the end of the body, where it will be \
executed with each iteration."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note that a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" loop \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["While[test, body]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" corresponds exactly to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[ , test, , body]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note that a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" loop \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Do[body, {x,xmin,xmax,xinc}]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" corresponds exactly to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["For[x=xmin, x<=xmax, x+=inc, body]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
WindowSize->{520, 509},
WindowMargins->{{Automatic, 32}, {26, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000002n88o?mooh<<H`Ui0fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@00000000000000060801T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 107, 2, 136, "Title",
  Evaluatable->False],
Cell[1841, 55, 98, 2, 26, "SmallText",
  Evaluatable->False],
Cell[1942, 59, 860, 31, 64, "Text",
  Evaluatable->False],
Cell[2805, 92, 404, 14, 54, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3234, 110, 113, 2, 50, "Section",
  Evaluatable->False],
Cell[3350, 114, 812, 24, 80, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4187, 142, 95, 2, 46, "Subsection",
  Evaluatable->False],
Cell[4285, 146, 1626, 52, 116, "Text",
  Evaluatable->False],
Cell[5914, 200, 224, 4, 162, "Input"],
Cell[6141, 206, 67, 1, 27, "Input"],

Cell[CellGroupData[{
Cell[6233, 211, 67, 1, 27, "Input"],
Cell[6303, 214, 150, 4, 36, "Message",
  Evaluatable->False]
}, Closed]],
Cell[6468, 221, 3633, 130, 166, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[10138, 356, 91, 2, 46, "Subsection",
  Evaluatable->False],
Cell[10232, 360, 1860, 62, 121, "Text",
  Evaluatable->False],
Cell[12095, 424, 266, 4, 177, "Input"],
Cell[12364, 430, 2118, 67, 164, "Text",
  Evaluatable->False],
Cell[14485, 499, 1774, 55, 131, "Text",
  Evaluatable->False],
Cell[16262, 556, 68, 1, 27, "Input"],
Cell[16333, 559, 69, 1, 27, "Input"],
Cell[16405, 562, 569, 20, 47, "Text",
  Evaluatable->False],
Cell[16977, 584, 71, 1, 27, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17097, 591, 79, 2, 30, "Section",
  Evaluatable->False],
Cell[17179, 595, 2126, 67, 163, "Text",
  Evaluatable->False],
Cell[19308, 664, 918, 29, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20251, 697, 122, 2, 46, "Subsection",
  Evaluatable->False],
Cell[20376, 701, 162, 4, 30, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20563, 709, 102, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[20668, 713, 91, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20796, 719, 99, 2, 42, "Subsubsection",
  Evaluatable->False],
Cell[20898, 723, 138, 3, 87, "Input"],
Cell[21039, 728, 2380, 74, 180, "Text",
  Evaluatable->False],
Cell[23422, 804, 776, 27, 50, "Text",
  Evaluatable->False],
Cell[24201, 833, 77, 1, 27, "Input"],
Cell[24281, 836, 1717, 60, 97, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26047, 902, 105, 2, 46, "Subsection",
  Evaluatable->False],
Cell[26155, 906, 126, 2, 30, "Text",
  Evaluatable->False],
Cell[26284, 910, 321, 5, 207, "Input"],
Cell[26608, 917, 70, 1, 27, "Input"],
Cell[26681, 920, 61, 1, 27, "Input"],
Cell[26745, 923, 819, 20, 111, "Text",
  Evaluatable->False],
Cell[27567, 945, 68, 1, 27, "Input"],
Cell[27638, 948, 141, 3, 87, "Input"],
Cell[27782, 953, 152, 3, 87, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27983, 962, 80, 2, 30, "Section",
  Evaluatable->False],
Cell[28066, 966, 1518, 48, 114, "Text",
  Evaluatable->False],
Cell[29587, 1016, 1288, 35, 128, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[30900, 1055, 95, 2, 46, "Subsection",
  Evaluatable->False],
Cell[30998, 1059, 181, 3, 87, "Input"],
Cell[31182, 1064, 2286, 85, 99, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[33505, 1154, 91, 2, 46, "Subsection",
  Evaluatable->False],
Cell[33599, 1158, 256, 4, 147, "Input"],
Cell[33858, 1164, 1515, 55, 82, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[35410, 1224, 122, 2, 46, "Subsection",
  Evaluatable->False],
Cell[35535, 1228, 132, 3, 72, "Input"],
Cell[35670, 1233, 1510, 55, 82, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[37217, 1293, 106, 2, 46, "Subsection",
  Evaluatable->False],
Cell[37326, 1297, 303, 5, 162, "Input"],
Cell[37632, 1304, 2806, 105, 99, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[40475, 1414, 85, 2, 46, "Subsection",
  Evaluatable->False],
Cell[40563, 1418, 252, 5, 46, "Text",
  Evaluatable->False],
Cell[40818, 1425, 724, 27, 48, "Text",
  Evaluatable->False],
Cell[41545, 1454, 746, 27, 48, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

