(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     53839,       1901]*)
(*NotebookOutlinePosition[     54924,       1936]*)
(*  CellTagsIndexPosition[     54880,       1932]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[" 23. Contexts and Packages"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision:  April 15 1998", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Although local variables and modules provide one way to organize data and \
protect some data from modification by certain functions, contexts and \
packages provide a better way to implement many of the same concepts.  In \
this section we introduce contexts and packages and provide examples of their \
use."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" operations/structures introduced: \n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["     ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["context",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox[
  "\n     Global`\n     System`Private`\n     Contexts[]\n     $Context\n     \
$ContextPath\n     Begin[]\n     End[]\n     BeginPackage[]\n     \
EndPackage[]\n     ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["shadowing",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["\n     Remove[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Contexts: Wider Scope"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "Recall that the appearance of the same name in two different places in \
code does not necessarily mean that the same variable or function is being \
referenced each time; the two names may in fact refer to different variables. \
 One primary example of this situation is when one uses local variables in a \
module:  the names declared local inside the module do not refer to variables \
with the same names defined outside of the module.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " treats the two different variables separately, even if one of the \
variables is undefined.  Here is an example, where we ask the value of an \
undefined local variable when a globally declared variable has already been \
defined:"
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Clear[x]\nx = 2;\ntestx[] := Module[{x},x];\ntestx[]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " assigns numbers to each occurence of the same name so that it can \
internally distinguish the different references, and in the code above, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" tells us with \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x$",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["\" that the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" inside the module is \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" number \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["\".  More importantly, however, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" does not return \"2\", the value of the globally declared \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Why would we want to use the same name for several different variables or \
functions?  Recall further that in the local variable case, we want to use \
names---descriptive ones, at that---without encroaching on the names the user \
of the program has already declared.  In short, we wish to reserve to \
ourselves, inside a program, names which the user need not know about and \
which will not affect any of the user's data or the user's choice of names.  \
"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Now a module is an excellent way to reserve names temporarily---while the \
module is running--but there are some drawbacks.  First, the variables are \
thrown away when the module is finished executing.  Second, suppose we have \
data which we would like to be separate from the user's data, shared between \
two certain functions, but protected from other functions.  Using modules, we \
would either have to make the data global (and hence lose the appropriate \
protections), or make the data local (in which case each function would not \
be allowed to reference the local data of the other).  What can we use to \
solve this problem?  The answer is a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["context",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Contexts are groupings of names (variables and functions) into categories \
such that variables or functions in ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["different",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" contexts with the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["same",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " names will be distinct yet will not be discarded at the end of execution \
of any particular function, as local variables are.  It is interesting to \
notice, then, that all of the non-local variables we have been declaring thus \
far have been in one particular context, the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["global",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" context.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Names of Contexts, Long Forms of Names"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The names of contexts are distinguished from the names of variables and \
functions by the fact that context names must be terminated by a particular \
character, a backwards single quote (\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\").  Hence \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyContext`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is a valid name of a context, while \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyContext",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is not.  Context names are used along with the (short) name of a \
variable or function if it is necessary to specify the particular context in \
which the variable or function resides.  To do so, the context name is added \
as a prefix to the (short) name of the variable, yielding the variable or \
function name's ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["long form",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[".  Hence, if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is in context \"MyContext`\" has long form \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyContext`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  The \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" defined above, outside the module, has long form \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  Note that contexts can be nested, i.e., it is possible to have a \
context inside a context.  If \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is in context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyContext`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" which is a context inside the context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", then its long form would be \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1`MyContext`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  As the name proceeds from left to right, the name becomes \
progressively more specific.  One nested context of particular interest is \
\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["System`Private`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", which contains all system variables, and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " programmers generally refrain from declaring new names in that context.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["To find a list of all current contexts, use the command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Contexts[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Contexts[]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Whenever contexts are referred to alone, they must be enclosed in \
quotation marks, because they are strings; whenever contexts are part of a \
long form of a variable or function name, they should not have quotation \
marks, because they are part of a name.  For example, to set variable \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Conx`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to \"2\", once should execute",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Conx`x = 2"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "On the other hand, if one wants instead to use a context name in a context \
command, such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Begin[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", used later in this section, one must execute an expression such as \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Begin[\"Con1`\"]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Default Contexts, Context Searches"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Names mentioned in code without an explicit context associated with them \
(such as \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\") always have ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["some",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" context associated to them, which is called the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["default ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox["context.  At the beginning of a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" session, the default context is \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", and all non-local user-created names are placed inside that context.  \
The default context, however, may be changed in a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" program.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  "'s searching algorithm, which determines exactly which variable a name \
such as \"x\" refers to, works as follows.  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " first looks for \"x\" in the default context, which is given by the value \
of the system variable \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["$Context",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  If ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" does not find \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in the default context, it then searches for \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" separately in each context, according to the order given in a certain \
list of contexts, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["$ContextPath",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", which is called the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["context search path",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[", and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" stops searching as soon as it finds an occurence of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", using the value of that particular \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Only if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is not found in any of these contexts will ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" determine that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" is a new name, associated to the default context.  The scope of a \
particular variable, then, is always determined by the value of the default \
context and the context search path; a particular variable may or may not be \
referenced when its short name is encountered.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Let's take a look to see what the values of the default context and the \
context search path are."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["$Context"], "Input",
  AspectRatioFixed->True],

Cell[TextData["$ContextPath"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"New Contexts, Declaring and Initializing Names, Packages"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[
"1: Establishing a context, Declaring with long forms"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "To establish a new context, we need only declare some names inside it.  \
There are three ways to declare a name in a context. The first way, which we \
now consider, is to refer to the name in the long form.  If we desire to \
initialize it, we may refer to the name on the left side of an assignment \
(\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["=",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\"), but we need only mention the name to have it declared.  Here are some \
examples.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["To set up a new context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["C1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", with an undefined name \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" declared inside, we could execute",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["C1`x;"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We run \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Contexts[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" again to see the addition of the context.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Contexts[]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["To initialize a variable \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["C1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" with value ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", we then execute",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["C1`y = 1"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  "The disadvantage of this first way of declaring names in a context is that \
long forms of names take a long time to write; in insuring that the names \
don't clash with other names from other contexts, we've lost the flexibility \
to use the names we would like, which are short.  We would like instead to \
instruct ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " that all names in a certain section of code refer to a particular \
context.  We move, then, to the second way to declare names in a context."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"2: Using the default context to declare names"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The second way to declare a name in a context is to change the default \
context.  When the default context is changed, all names declared in \
subsequent lines of code without specified contexts are placed inside this \
new context, and this effect remains until the default context is changed \
back.  In order to change the default context, we execute the command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Begin[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", with (a string containing) the context name as the parameter.  \
(Alternatively, one can simply assign a new string to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["$Context",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".)  When we would like to change the default context back, we execute \
the command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["End[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which has no parameters.  (Alternatively, we could assign \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["$Context",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".)  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["An important fact to remember when changing contexts is that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" determines the context of each name for an entire cell ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["before",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " it executes any statement in the cell.  Thus, issuing a command to change \
the context must be in a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["separate",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " cell from any name which is to use the new context; otherwise, the names \
will be interpreted in the old context before executing the cell containing \
the command to change the context.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["To initialize \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["z",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" inside a context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", we should first execute the following:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Begin[\"Con1`\"];"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Note that this context change was in a separate cell.  Then we execute"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["x = 1; y = 2; z = 3;"], "Input",
  AspectRatioFixed->True],

Cell[TextData["x\ny\nz"], "Input",
  AspectRatioFixed->True],

Cell["", "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Everything looks fine, no.  However, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["not declared ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" in context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" was already declared at the top of the section.  Why not?  The reason \
is that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" looked to see if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" had already been declared, either in the default context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", or any context in the search path.  Since there had already been a \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" declared, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" decided that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was not a new name, and set \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to 1.  One might think it would determine that a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" had already been defined (in context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["C1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", but \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["C1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" has not been added to the context search path, so ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" treats the use of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" as a new variable, and creates it in the default context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\". ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "To dispel some of this unfortunate confusion resulting from contexts, it \
is useful to ask ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" what the context of some variable is, using the command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Context[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which simply returns the context of the parameter.  Let's see what the \
contexts of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["z",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" are.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Context[x]\nContext[y]\nContext[z]\n"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Before any new confusion happens, let's reset the default context back to \
\"Global`\"."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["End[];"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"The notion of using a default context as we did to declare new names in a \
context is, then, fraught with danger in that it is possible to make a \
mistake, to miss declaring a new name in a context because the name has \
already been used in another context which is listed in the search path.  We \
move, then, to the third way to declare names in a context.  "], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[
"3: Using BeginPackage, EndPackage to declare names"], "Subsubsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The third way is to change the default context to our new context ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["and",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" change the context search path so that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " is not allowed to \"find\" any other variables or functions with the same \
names as the ones we are defining; then ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " must declare the new names within the default context.  We could do so by \
explicitly changing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["$Context",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["$ContextPath",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", but ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" provides a simpler method, using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["BeginPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["EndPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "What \"BeginPackage[s]\" does is take the argument \"s\" (a string with a \
context name), set the default context to \"s\", and alter the context search \
path to be a two-element list consisting of the list \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{s,\"System`\"}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  The command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["EndPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" restores the default context and the context search path back to the \
values they had when \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["BeginPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was executed---except that \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["s",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is the added to the front of the search path. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["What is the effect of using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["BeginPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["EndPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"?  First, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["BeginPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" changes the default context and search path so that any name (which is \
not a system name) will necessarily refer to the new context, since the \
default context is the new context and the search path does not contain any \
other context, including \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  Then, after we have created the names we want in the new context, \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["EndPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" restores the default context and the search path, and the name of the \
new context is added to the search path so that we can access the variables \
and functions from the new context without using a long form.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "As an example, let's declare a context \"Con2\" with three variables \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["z",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  We do not worry about their previous definitions, either in \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" or \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con1`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", since we are using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["BeginPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["EndPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["BeginPackage[\"Con2`\"]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Again, note that the context change command is in a line by itself."], "Text",\

  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["x = 1; y = 2; z = 3;"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["What does \"shadowing\" mean in the red ink?  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " is warning us that we are defining a name which has another incarnation \
in another context.  This is true:  there is a \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["EndPackage[]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now there are three new variables, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con2`x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con2`y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con2`z",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  To check, let's ask what their definitions are.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Con2`x\nCon2`y\nCon2`z"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We can also reference these values by their short forms \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["z",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", because \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Con2`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" occurs first in the search path after \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["EndPackage[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\":",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["$ContextPath"], "Input",
  AspectRatioFixed->True],

Cell[TextData["x\ny\nz"], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Undeclaring Names"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Up to now, we have used \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Clear[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to erase the definitions of a name.  However, using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Clear[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" with contexts will only clear definitions---the definitions of a \
particular variable or function referred to by the parameter---but will not \
erase the \"mentioning\" of the name.  In other words, if \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" was defined in the context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", then using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Clear[Global`x]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" will still leave an \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" declared in the context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  As we have seen in situations above, we may wish to completely \
undeclare a name from all contexts. To do so, use the command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Remove[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Examples"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"We work through some sections of code and decipher names in several \
contexts."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["1"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Remove[tie]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["BeginPackage[\"MyP`\"]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["tie[x_,y_] := x+y"], "Input",
  AspectRatioFixed->True],

Cell[TextData["EndPackage[]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The result of the preceding code is to erase all declarations of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" from ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[", to establish a context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" which has a definition of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in it, to add \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" to the context search path, and to return the default context to the \
original one.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Hence \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[1,2]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" should return 3, since ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" can find \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in one of the contexts in the search path (\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\"):",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["tie[1,2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["However, there should be no definition of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in the global context.  We can check this:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["?Global`tie"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["2"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["BeginPackage[\"YourP`\"]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["tie[x_,y_] := x*y"], "Input",
  AspectRatioFixed->True],

Cell[TextData["EndPackage[]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Now, the result should be that a new context \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["YourP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is declared, with a definition of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" inside it, and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["YourP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" will be added to the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["front",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox["  of the context search path, so \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["YourP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" will be the first context checked for the definition of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Hence executing \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[1,2]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" now should yield \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Delphian"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["tie[1,2]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Let's check our definitions."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["?MyP`tie"], "Input",
  AspectRatioFixed->True],

Cell[TextData["?YourP`tie"], "Input",
  AspectRatioFixed->True],

Cell[TextData["?tie"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Notice that ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" again tried \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["YourP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" first, in order to find a definition for \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  The context search path should have \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["YourP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in front.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["$ContextPath"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["3"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Now we look at the effect of changing default contexts on the execution of \
code."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We'll set the default context to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["MyP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" and evaluate \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["tie[2,3]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["$Context = \"MyP`\""], "Input",
  AspectRatioFixed->True],

Cell[TextData["tie[2,3]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["We have the expected result, 5, since ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" checked the default context first.  We can always force ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" to use the definition from \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["YourP`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" by using the long form:",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["YourP`tie[2,3]"], "Input",
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
WindowSize->{602, 554},
WindowMargins->{{92, Automatic}, {15, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003809T?o>old</PW30fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@5caU0000000000060801T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 101, 2, 98, "Title",
  Evaluatable->False],
Cell[1835, 55, 98, 2, 26, "SmallText",
  Evaluatable->False],
Cell[1936, 59, 384, 7, 62, "Text",
  Evaluatable->False],
Cell[2323, 68, 1016, 35, 194, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[3364, 107, 98, 2, 50, "Section",
  Evaluatable->False],
Cell[3465, 111, 810, 15, 112, "Text",
  Evaluatable->False],
Cell[4278, 128, 105, 1, 50, "Input"],
Cell[4386, 131, 1866, 67, 51, "Text",
  Evaluatable->False],
Cell[6255, 200, 535, 9, 64, "Text",
  Evaluatable->False],
Cell[6793, 211, 971, 22, 90, "Text",
  Evaluatable->False],
Cell[7767, 235, 1067, 33, 64, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8859, 272, 118, 2, 42, "Subsection",
  Evaluatable->False],
Cell[8980, 276, 3698, 118, 155, "Text",
  Evaluatable->False],
Cell[12681, 396, 376, 13, 25, "Text",
  Evaluatable->False],
Cell[13060, 411, 63, 1, 22, "Input"],
Cell[13126, 414, 817, 24, 51, "Text",
  Evaluatable->False],
Cell[13946, 440, 63, 1, 22, "Input"],
Cell[14012, 443, 674, 24, 38, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[14723, 472, 114, 2, 42, "Subsection",
  Evaluatable->False],
Cell[14840, 476, 1513, 52, 64, "Text",
  Evaluatable->False],
Cell[16356, 530, 3324, 111, 116, "Text",
  Evaluatable->False],
Cell[19683, 643, 173, 4, 25, "Text",
  Evaluatable->False],
Cell[19859, 649, 61, 1, 22, "Input"],
Cell[19923, 652, 65, 1, 22, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[20025, 658, 137, 3, 42, "Subsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20187, 665, 136, 3, 33, "Subsubsection",
  Evaluatable->False],
Cell[20326, 670, 707, 20, 64, "Text",
  Evaluatable->False],
Cell[21036, 692, 563, 20, 25, "Text",
  Evaluatable->False],
Cell[21602, 714, 58, 1, 22, "Input"],
Cell[21663, 717, 368, 13, 25, "Text",
  Evaluatable->False],
Cell[22034, 732, 63, 1, 22, "Input"],
Cell[22100, 735, 709, 27, 25, "Text",
  Evaluatable->False],
Cell[22812, 764, 61, 1, 22, "Input"],
Cell[22876, 767, 598, 12, 64, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[23511, 784, 129, 3, 33, "Subsubsection",
  Evaluatable->False],
Cell[23643, 789, 1664, 51, 90, "Text",
  Evaluatable->False],
Cell[25310, 842, 1063, 32, 64, "Text",
  Evaluatable->False],
Cell[26376, 876, 898, 34, 25, "Text",
  Evaluatable->False],
Cell[27277, 912, 70, 1, 22, "Input"],
Cell[27350, 915, 148, 4, 25, "Text",
  Evaluatable->False],
Cell[27501, 921, 73, 1, 22, "Input"],
Cell[27577, 924, 60, 1, 40, "Input"],
Cell[27640, 927, 43, 1, 22, "Input"],
Cell[27686, 930, 3619, 129, 90, "Text",
  Evaluatable->False],
Cell[31308, 1061, 1249, 45, 51, "Text",
  Evaluatable->False],
Cell[32560, 1108, 89, 1, 50, "Input"],
Cell[32652, 1111, 163, 4, 25, "Text",
  Evaluatable->False],
Cell[32818, 1117, 59, 1, 22, "Input"],
Cell[32880, 1120, 438, 7, 51, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[33355, 1132, 134, 3, 33, "Subsubsection",
  Evaluatable->False],
Cell[33492, 1137, 1916, 67, 64, "Text",
  Evaluatable->False],
Cell[35411, 1206, 1250, 39, 64, "Text",
  Evaluatable->False],
Cell[36664, 1247, 1625, 50, 90, "Text",
  Evaluatable->False],
Cell[38292, 1299, 1529, 57, 38, "Text",
  Evaluatable->False],
Cell[39824, 1358, 76, 1, 22, "Input"],
Cell[39903, 1361, 144, 4, 25, "Text",
  Evaluatable->False],
Cell[40050, 1367, 73, 1, 22, "Input"],
Cell[40126, 1370, 661, 22, 38, "Text",
  Evaluatable->False],
Cell[40790, 1394, 65, 1, 22, "Input"],
Cell[40858, 1397, 754, 27, 25, "Text",
  Evaluatable->False],
Cell[41615, 1426, 75, 1, 40, "Input"],
Cell[41693, 1429, 1107, 41, 38, "Text",
  Evaluatable->False],
Cell[42803, 1472, 65, 1, 22, "Input"],
Cell[42871, 1475, 60, 1, 40, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42980, 1482, 97, 2, 42, "Subsection",
  Evaluatable->False],
Cell[43080, 1486, 2036, 67, 77, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[45165, 1559, 85, 2, 30, "Section",
  Evaluatable->False],
Cell[45253, 1563, 154, 4, 25, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[45432, 1571, 81, 2, 42, "Subsection",
  Evaluatable->False],
Cell[45516, 1575, 64, 1, 22, "Input"],
Cell[45583, 1578, 75, 1, 22, "Input"],
Cell[45661, 1581, 70, 1, 22, "Input"],
Cell[45734, 1584, 65, 1, 22, "Input"],
Cell[45802, 1587, 1227, 44, 51, "Text",
  Evaluatable->False],
Cell[47032, 1633, 918, 34, 38, "Text",
  Evaluatable->False],
Cell[47953, 1669, 61, 1, 22, "Input"],
Cell[48017, 1672, 399, 13, 25, "Text",
  Evaluatable->False],
Cell[48419, 1687, 64, 1, 22, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48520, 1693, 81, 2, 42, "Subsection",
  Evaluatable->False],
Cell[48604, 1697, 77, 1, 22, "Input"],
Cell[48684, 1700, 70, 1, 22, "Input"],
Cell[48757, 1703, 65, 1, 22, "Input"],
Cell[48825, 1706, 1761, 62, 52, "Text",
  Evaluatable->False],
Cell[50589, 1770, 61, 1, 22, "Input"],
Cell[50653, 1773, 102, 2, 25, "Text",
  Evaluatable->False],
Cell[50758, 1777, 61, 1, 22, "Input"],
Cell[50822, 1780, 63, 1, 22, "Input"],
Cell[50888, 1783, 57, 1, 22, "Input"],
Cell[50948, 1786, 948, 34, 38, "Text",
  Evaluatable->False],
Cell[51899, 1822, 65, 1, 22, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[52001, 1828, 81, 2, 42, "Subsection",
  Evaluatable->False],
Cell[52085, 1832, 157, 4, 25, "Text",
  Evaluatable->False],
Cell[52245, 1838, 536, 20, 25, "Text",
  Evaluatable->False],
Cell[52784, 1860, 72, 1, 22, "Input"],
Cell[52859, 1863, 61, 1, 22, "Input"],
Cell[52923, 1866, 806, 27, 38, "Text",
  Evaluatable->False],
Cell[53732, 1895, 67, 1, 22, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

