(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     62986,       1867]*)
(*NotebookOutlinePosition[     64064,       1902]*)
(*  CellTagsIndexPosition[     64020,       1898]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData["Chapter IX.  Special Topics"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[" 27. Fits and Graphics"], "Title",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell["Last revision:  April 15 1998", "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "In this last section, we explore ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s graphics commands and \"Fit[]\" function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" operations/structures introduced: \n",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[
  "     ListPlot[]\n     Fit[]\n     DisplayFunction->Identity\n     \
DisplayFunction->$DisplayFunction\n     Show[]\n     Graphics[]\n     \
Point[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Line[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Rectangle[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Polygon[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Circle[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Disk[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Raster[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Text[] \n     Dashing[]  GrayLevel[]  Thickness[] ",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"]
}], "SmallText",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Fits"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Back in the Classroom"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Suppose, as we did earlier in the course, that an instructor likes to ask \
students in a class for answers to homework questions.  If the instructor \
asks for answers to \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["n",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" questions, and there are \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["m",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" students in the class, how many different students are likely to be \
called on?  We can attempt to decide by writing a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" function which mimics this classroom situation. ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"roster={\"Andrews\",\"Biber\",\"Chase\",\"Cowles\",\n\
\"Dearing\",\"Elzayadi\",\"Ferrentino\",\"Hsieh\",\"Jones\",\n\
\"Kavanagh\",\"Minlend\",\"Montague\",\"Peay\",\"Smith\",\n\
\"Sparks\",\"Stovesand\",\"Symes\",\"Talvacchio\"};\nnumStudents = \
Length[roster];\n\nClear[draw,numQuestions]\ndraw[numQuestions_] := Length[\n \
  Union[\n     Table[ \n        roster[[ Random[Integer,{1,numStudents}] ]],\n\
        {numQuestions}\n     ]\n   ]\n]\n\nClear[aveDraw,numCalled,trials]\n\
aveDraw[numCalled_,trials_] := \n   N[ Sum[draw[numCalled],{trials}]/trials \
]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The numeric answer may be interesting in its own right, but we may learn \
more about the function by finding a graphical representation of the \
function.  We can do so by using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ListPlot[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  We'll plot the number of questions asked on the x-axis and the \
resulting average number of different students called upon on the y-axis.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"aveData = Table[ \n  {numQuestions, aveDraw[numQuestions,5]},\n  \
{numQuestions,1,100}] ;  "], "Input",
  AspectRatioFixed->True],

Cell[TextData["dataPlot = ListPlot[aveData]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Unfortunately, on some monitors, the default plot size makes the points \
too small to see.  If this is true on your monitor, read the rest of the \
paragraph; otherwise, you may want to skip it.  One solution is to use the \
option \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Prolog->PointSize[.02]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["ListPlot[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" call (making it a final parameter), but we must keep in mind that the \
\"PointSize\" parameter affects different monitors and printers to differing \
amounts, so that if we're not careful, the points will print out much larger \
than they appear on the screen.  Another solution is simply to expand the \
graphic:  click on the graphic, grab a corner, and drag it to a larger size.  \
(Note: graphics take up lots of space in on your disk, so you may want to \
delete cells with graphics before saving.) ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"After looking at a plot of the data, we may believe that some function \
approximates the values.  We search for such a function below."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Finding an Analytic Function to Match the Data"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "What we'd like to do now is \"fit\" a curve or function to the data in the \
list \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["aveData",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  In other words, we would like to determine an analytic function, say \
polynomial, trigonometric, or otherwise, which will match the data points we \
have.   We might use the function later to guess what some values of data \
would be, say with a number of questions too large to give to our \"aveDraw\" \
function.  The ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" function needed is the function \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fit[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["?Fit"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "We'll feed the Fit function our list of x-y pairs, a list of \"building \
functions\", and the variable we want to use for the function.  ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " is allowed to choose any sum of any multiples of the function when \
finding the \"best fit\"; i.e., if the building functions are \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{f[x], g[x], h[x]}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", then \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fit[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" finds the best curve of the form \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a f[x] + b g[x] + c h[x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["]\", where \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["b",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["c",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" are numbers.  ",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["fitter[x_] = Fit[aveData,{1,x,x^2},x]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Here, given building functions \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["1",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x^2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fit[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" command finds the best coefficients of all possible curves of the form \
",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["a*(1) + b*(x) + c*(x^2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ", i.e. of all possible parabolas.  When your instructor ran this command \
the result was the sum of ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["3.82261*(1)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox[".450069*(x)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[", and ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["-.00305751*(x^2)",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  ". You may find slightly different results because we used the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Random[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" function in creating the list \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["aveData",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".   Let's look at the plot.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["fitterPlot = Plot[ fitter[x],{x,1,100}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "This doesn't look too much like our previous plot, but one problem is that \
not the entire graph was shown.  To see the complete graph we need to add the \
option \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotRange->All",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fitterPlot]\nfitterPlot = Plot[fitter[x],{x,1,100},\n\t\t  \
PlotRange->All]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"This looks a little closer, but let's see how it holds up when we show the \
function and the data together."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[fitterPlot,dataPlot]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["That's not too bad, but we can do better by giving the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fit[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" command more \"building functions\" with which to construct the \
approximating function.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Clear[fitter,fitterPlot]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["fitter[x_]=Fit[aveData,{1,x,x^2,x^3},x]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"fitterPlot=Plot[ fitter[x],{x,1,100},\n\tPlotRange->All]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["Show[fitterPlot,dataPlot]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The real trick to using the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fit[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" function is in finding good building functions to use.  By doing many \
experiments, one finds that the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Fit[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" function does very well when given ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["{1,x,1/(x+20)}",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[" as building functions.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Clear[fitter,fitterPlot]\nfitter[x_]=Fit[aveData,{1,x,1/(x+20)},x]\n\
fitterPlot=Plot[fitter[x],{x,1,100},\n\tDisplayFunction->Identity]\n\
Show[dataPlot,fitterPlot,\n DisplayFunction->$DisplayFunction]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Note:  the option \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["DisplayFunction->Identity",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" suppresses the output of the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" function, and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["DisplayFunction->$DisplayFunction",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" forces the output to appear.  (Sometimes this last expression is \
unnecessary, but remembering to use it when \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["DisplayFunction->Identity",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" is used is wise.)",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Graphics, Primitives"], "Section",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData["Showing by Doing, Doing by Showing"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88889 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.12963 0.42328 0.021164 0.42328 [
[(0.5)] .34127 .02116 0 2 Msboxa
[(1)] .55291 .02116 0 2 Msboxa
[(1.5)] .76455 .02116 0 2 Msboxa
[(2)] .97619 .02116 0 2 Msboxa
[(0.5)] .11713 .2328 1 0 Msboxa
[(1)] .11713 .44444 1 0 Msboxa
[(1.5)] .11713 .65608 1 0 Msboxa
[(2)] .11713 .86772 1 0 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .88989 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.34127 .02116 m
.34127 .02741 L
s
P
[(0.5)] .34127 .02116 0 2 Mshowa
p
.002 w
.55291 .02116 m
.55291 .02741 L
s
P
[(1)] .55291 .02116 0 2 Mshowa
p
.002 w
.76455 .02116 m
.76455 .02741 L
s
P
[(1.5)] .76455 .02116 0 2 Mshowa
p
.002 w
.97619 .02116 m
.97619 .02741 L
s
P
[(2)] .97619 .02116 0 2 Mshowa
p
.001 w
.17196 .02116 m
.17196 .02491 L
s
P
p
.001 w
.21429 .02116 m
.21429 .02491 L
s
P
p
.001 w
.25661 .02116 m
.25661 .02491 L
s
P
p
.001 w
.29894 .02116 m
.29894 .02491 L
s
P
p
.001 w
.3836 .02116 m
.3836 .02491 L
s
P
p
.001 w
.42593 .02116 m
.42593 .02491 L
s
P
p
.001 w
.46825 .02116 m
.46825 .02491 L
s
P
p
.001 w
.51058 .02116 m
.51058 .02491 L
s
P
p
.001 w
.59524 .02116 m
.59524 .02491 L
s
P
p
.001 w
.63757 .02116 m
.63757 .02491 L
s
P
p
.001 w
.67989 .02116 m
.67989 .02491 L
s
P
p
.001 w
.72222 .02116 m
.72222 .02491 L
s
P
p
.001 w
.80688 .02116 m
.80688 .02491 L
s
P
p
.001 w
.84921 .02116 m
.84921 .02491 L
s
P
p
.001 w
.89153 .02116 m
.89153 .02491 L
s
P
p
.001 w
.93386 .02116 m
.93386 .02491 L
s
P
p
.001 w
.0873 .02116 m
.0873 .02491 L
s
P
p
.001 w
.04497 .02116 m
.04497 .02491 L
s
P
p
.001 w
.00265 .02116 m
.00265 .02491 L
s
P
p
.002 w
0 .02116 m
1 .02116 L
s
P
p
.002 w
.12963 .2328 m
.13588 .2328 L
s
P
[(0.5)] .11713 .2328 1 0 Mshowa
p
.002 w
.12963 .44444 m
.13588 .44444 L
s
P
[(1)] .11713 .44444 1 0 Mshowa
p
.002 w
.12963 .65608 m
.13588 .65608 L
s
P
[(1.5)] .11713 .65608 1 0 Mshowa
p
.002 w
.12963 .86772 m
.13588 .86772 L
s
P
[(2)] .11713 .86772 1 0 Mshowa
p
.001 w
.12963 .06349 m
.13338 .06349 L
s
P
p
.001 w
.12963 .10582 m
.13338 .10582 L
s
P
p
.001 w
.12963 .14815 m
.13338 .14815 L
s
P
p
.001 w
.12963 .19048 m
.13338 .19048 L
s
P
p
.001 w
.12963 .27513 m
.13338 .27513 L
s
P
p
.001 w
.12963 .31746 m
.13338 .31746 L
s
P
p
.001 w
.12963 .35979 m
.13338 .35979 L
s
P
p
.001 w
.12963 .40212 m
.13338 .40212 L
s
P
p
.001 w
.12963 .48677 m
.13338 .48677 L
s
P
p
.001 w
.12963 .5291 m
.13338 .5291 L
s
P
p
.001 w
.12963 .57143 m
.13338 .57143 L
s
P
p
.001 w
.12963 .61376 m
.13338 .61376 L
s
P
p
.001 w
.12963 .69841 m
.13338 .69841 L
s
P
p
.001 w
.12963 .74074 m
.13338 .74074 L
s
P
p
.001 w
.12963 .78307 m
.13338 .78307 L
s
P
p
.001 w
.12963 .8254 m
.13338 .8254 L
s
P
p
.002 w
.12963 0 m
.12963 .88889 L
s
P
P
0 0 m
1 0 L
1 .88889 L
0 .88889 L
closepath
clip
newpath
p
p
1 0 0 r
.12963 .02116 m
.55291 .02116 L
.55291 .44444 L
F
P
p
.628 .126 .941 r
.004 w
.12963 .44444 m
.12963 .44444 .10582 0 365.73 arc
F
P
p
1 1 0 r
.004 w
newpath
.55291 .44444 .10582 0 365.73 arc
s
P
p
.855 .647 .126 r
[ .01 ] 0 setdash
.004 w
.12963 .44444 m
.55291 .02116 L
.97619 .44444 L
.55291 .86772 L
.12963 .44444 L
s
P
p
[(Soda Shop or Cosmic Coffee?)] .55291 .65608 0 0 Mshowa
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  Evaluatable->False,
  AspectRatioFixed->True,
  ImageSize->{440, 389},
  ImageMargins->{{35, Inherited}, {Inherited, Inherited}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006h0001QA000`40O003h00Oogoo^Goo003oOoni
Ool00?mookUoo`00T7oo0P0017oo0P000goo0`00DWoo0`00DWoo0`0017oo0P000goo0`00DGoo1000
3goo002?Ool01000Oomoo`000goo0P001Woo00<007ooOol0D7oo00<007ooOol0DWoo00<007ooOol0
0goo0P001Woo00<007ooOol0Cgoo00<007ooOol03goo002?Ool01000Oomoo`002goo00<007ooOol0
D7oo00<007ooOol0DWoo00<007ooOol02goo00<007ooOol0D7oo00<007ooOol03Woo000lOol00`00
Oomoo`1@Ool01000Oomoo`0027oo0`00Dgoo00<007ooOol0DWoo00<007ooOol027oo0`00E7oo00<0
07ooOol03Goo000lOol00`00Oomoo`1@Ool01000Oomoo`0027oo00<007ooOol0Dgoo00<007ooOol0
DWoo00<007ooOol027oo00<007ooOol0DGoo00@007ooOol000moo`00?7oo00<007ooOol0DGoo0P00
2Goo1000DGoo0P00Dgoo0P002Woo1000DGoo0P0047oo000lOol00`00Oomoo`3oOomjOol003aoo`03
001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`3oOomjOol003aoo`03
001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo0004Oooo002`0005Ool000Eoo`03001oogoo
011oo`03001oogoo00moo`03001oogoo00moo`03001l07`00;=l0003KXAoogoo00moo`03001oogoo
00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo011oo`03001oogoo00moo`03001oogoo
00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00ioo`001Goo00<0
07ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooO000/g`000<006j4Ool03goo00<0
07ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03Woo000l
Ool00`00Oomoo`2`O0001Vj4O01l0000Oom^Q5Qoo`03001oogoo05Moo`03001oogoo00ioo`00?7oo
00@007ooOomoojil0004KXAl07`0O003Ool00fj4Oomoo`30Ool003aoo`03001oogoo009oojal0003
KXAl07`0009l0<Ioo`00?7oo00<007ooOol00gooZW`000=^Q7`0O0000g`0aWoo000lOol00`00Oomo
o`04Oon_O006Ool00fj4Oomoo`2mOol003aoo`03001oogoo00Eoojil00Moo`03KXAoogoo0;aoo`00
?7oo00<007ooOol01WooY7`000=^Q7`0O0001W`027oo00=^Q7ooOol0^goo000lOol00`00Oomoo`07
OonRO0000fj4O01l0007O009Ool00fj4Oomoo`2jOol003aoo`03001oogoo00Qooj1l0003KXAl07`0
00Ql0<Ioo`00?7oo00<007ooOol02GooWW`000=^Q7`0O0002G`0aWoo000lOol00`00Oomoo`0:OonY
O00<Ool00fj4Oomoo`2gOol003aoo`03001oogoo00]oojQl00eoo`03KXAoogoo0;Ioo`00?7oo00<0
07ooOol037ooV7`000=^Q7`0O00037`03Woo00=^Q7ooOol0]Goo000lOol00`00Oomoo`0=OonFO000
0fj4O01l000=O00?Ool00fj4Oomoo`2dOol003aoo`03001oogoo00iooiAl0003KXAl07`000il0<Io
o`00?7oo00<007ooOol03gooTW`000=^Q7`0O0003g`0aWoo000lOol3000@OonSO00BOol00fj4Oomo
o`2aOol003aoo`03001oogoo015ooj9l01=oo`03KXAoogoo0;1oo`00?7oo00<007ooOol04WooS7`0
00=^Q7`0O0004W`057oo00=^Q7ooOol0[goo000lOol00`00Oomoo`0COon:O0000fj4O01l000CO00E
Ool00fj4Oomoo`2^Ool003aoo`03001oogoo01AoohQl0003KXAl07`001Al0<Ioo`00?7oo00<007oo
Ool05GooQW`000=^Q7`0O0005G`0aWoo000lOol00`00Oomoo`0FOonMO00HOol00fj4Oomoo`2[Ool0
03aoo`03001oogoo01Mooial01Uoo`03KXAoogoo0:Yoo`00?7oo00<007ooOol067ooP7`000=^Q7`0
O00067`06Woo00=^Q7ooOol0ZGoo000lOol00`00Oomoo`0IOomnO0000fj4O01l000IO00KOol00fj4
Oomoo`2XOol003aoo`03001oogoo01Yoogal0003KXAl07`001Yl0<Ioo`00?7oo00<007ooOol06goo
NW`000=^Q7`0O0006g`0aWoo000lOol00`00Oomoo`0LOonGO00NOol00fj4Oomoo`2UOol003aoo`03
001oogoo01eooiIl01moo`03KXAoogoo0:Aoo`00?7oo00<007ooOol07WooM7`000=^Q7`0O0007W`0
87oo00=^Q7ooOol0Xgoo000lOol00`00Oomoo`0OOomcO0000fj4O01l000NO00QOol00fj4Oomoo`2R
Ool003aoo`03001oogoo021oog5l0003KXAl07`001ml0<Ioo`00?7oo00<007ooOol08GooKg`000=^
Q7`0O00087`0aWoo000lOol3000ROom]O0000fj4O01l000QO00UOol00fj4Oomoo`2NOol003aoo`03
001oogoo02=ooi1l02Ioo`03KXAoogoo09eoo`00?7oo00<007ooOol097ooSg`09goo00=^Q7ooOol0
W7oo000lOol00`00Oomoo`0UOomWO0000fj4O01l000TO00XOol00fj4Oomoo`2KOol003aoo`03001o
ogoo02IoofEl0003KXAl07`002El0<Ioo`00?7oo00<007ooOol09gooHg`000=^Q7`0O0009W`0aWoo
000lOol00`00Oomoo`0XOomQO0000fj4O01l000WO00[Ool00fj4Oomoo`2HOol003aoo`03001oogoo
02UoohYl02aoo`03KXAoogoo09Moo`00?7oo00<007ooOol0:WooRG`0;Goo00=^Q7ooOol0UWoo000l
Ool00`00Oomoo`0[OomKO0000fj4O01l000ZO00^Ool00fj4Oomoo`2EOol003aoo`03001oogoo02ao
oeUl0003KXAl07`002]l0<Ioo`00?7oo00<007ooOol0;GooEg`000=^Q7`0O000;7`0aWoo000lOol0
0`00Oomoo`0^OomEO0000fj4O01l000]O00aOol00fj4Oomoo`2BOol003aoo`03001oogoo02moohAl
035oo`03KXAoogoo099oo`00?7oo00<007ooOol0<7ooPg`0<Woo00=^Q7ooOol0TGoo000lOol00`00
Oomoo`0aOom>O0000fj4O01l000aO00cOol00fj4Oomoo`2@Ool003aoo`03001oogoo039oodal0003
KXAl07`0039l03Aoo`03KXAoogoo08moo`00?7oo00<007ooOol0<gooBW`000=^Q7`0O000<g`0aWoo
000lOol3000dOom8O0000fj4O01l000dO036Ool003aoo`03001oogoo03Eoogil03Moo`03KXAoogoo
08aoo`00?7oo00<007ooOol0=WooOG`0>7oo00=^Q7ooOol0Rgoo000lOol00`00Oomoo`0gOom2O000
0fj4O01l000gO00iOol00fj4Oomoo`2:Ool003aoo`03001oogoo03Qood1l0003KXAl07`003Ql03Yo
o`03KXAoogoo08Uoo`00?7oo00<007ooOol0>Goo?W`000=^Q7`0O000>G`0aWoo000lOol00`00Oomo
o`0jOollO0000fj4O01l000jO036Ool003aoo`03001oogoo03]oogQl03eoo`03KXAoogoo08Ioo`00
?7oo00<007ooOol0?7ooMg`0?Woo00=^Q7ooOol0QGoo000lOol00`00Oomoo`0mOolfO0000fj4O01l
000mO00oOol00fj4Oomoo`24Ool003aoo`03001oogoo03ioocAl0003KXAl07`003il041oo`03KXAo
ogoo08=oo`00?7oo00<007ooOol0?goo<W`000=^Q7`0O000?g`0aWoo000lOol00`00Oomoo`10Ool`
O0000fj4O01l0010O036Ool003aoo`03001oogoo045oog9l04=oo`03KXAoogoo081oo`00?7oo00<0
07ooOol0@WooLG`0A7oo00=^Q7ooOol0Ogoo000lOol00`00Oomoo`13OolZO0000fj4O01l0013O015
Ool00fj4Oomoo`1nOol003aoo`03001oogoo04AoobQl0003KXAl07`004Al04Ioo`03KXAoogoo07eo
o`00?7oo00<007ooOol0AGoo9W`000=^Q7`0O000AG`0aWoo000lOol30016OolTO0000fj4O01l0016
O036Ool003aoo`03001oogoo04Moofal04Uoo`03KXAoogoo07Yoo`00?7oo00<007ooOol0B7ooJg`0
BWoo00=^Q7ooOol0NGoo000lOol00`00Oomoo`19OolNO0000fj4O01l0019O01;Ool00fj4Oomoo`1h
Ool003aoo`03001oogoo04Yooaal0003KXAl07`004Yl04aoo`03KXAoogoo07Moo`00?7oo00<007oo
Ool0Bgoo6W`000=^Q7`0O000Bg`0aWoo000lOol00`00Oomoo`1<OolHO0000fj4O01l001<O036Ool0
03aoo`03001oogoo04eoofIl04moo`03KXAoogoo07Aoo`00?7oo00<007ooOol0CWooIG`0D7oo00=^
Q7ooOol0Lgoo000lOol00`00Oomoo`1?OolBO0000fj4O01l001?O01AOol00fj4Oomoo`1bOol003ao
o`03001oogoo051ooa1l0003KXAl07`0051l059oo`03KXAoogoo075oo`00?7oo00<007ooOol0DGoo
3W`000=^Q7`0O000DG`0aWoo000lOol00`00Oomoo`1BOol<O0000fj4O01l001BO036Ool003aoo`03
001oogoo05=oof1l05Eoo`03KXAoogoo06ioo`00?7oo00<007ooOol0E7ooGg`0EWoo00=^Q7ooOol0
KGoo000lOol00`00Oomoo`1EOol6O0000fj4O01l001EO01GOol00fj4Oomoo`1/Ool002Moo`8000Ao
o`8000=oo`<000Moo`03001oogoo05Ioo`Al0003KXAl07`005Il05Qoo`03KXAoogoo06]oo`009Woo
00@007ooOol000=oo`8000Ioo`03001oogoo00Aoo`03001oogoo05Moo`9l0003KXAl07`005Ml0<Io
o`009Woo00@007ooOol000]oo`03001oogoo00Aoo`@005Moo`03KXAl07`005Ql0<Ioo`009Woo00@0
07ooOol000Qoo`<000Moo`03001oogoo05UooeYl05]oo`03KXAoogoo06Qoo`009Woo00@007ooOol0
00Qoo`03001oogoo00Moo`03001oogoo05YooeUl05aoo`03KXAoogoo06Moo`009goo0P002Goo1000
1Woo00<007ooOol0EGoo00=^Q7ooOol00gooF7`0GGoo00=^Q7ooOol0IWoo000lOol00`00Oomoo`1D
Ool00fj4Oomoo`05OomGO01NOol00fj4Oomoo`1UOol003aoo`03001oogoo05=oo`03KXAoogoo00Mo
oeIl0<Ioo`00?7oo00<007ooOol0DWoo00=^Q7ooOol02GooEG`0aWoo000lOol00`00Oomoo`1OOomD
O01QOol00fj4Oomoo`1ROol003aoo`03001oogoo061ooe=l069oo`03KXAoogoo065oo`00?7oo00<0
07ooOol0Cgoo00=^Q7ooOol03gooDW`0Hgoo00=^Q7ooOol0H7oo000lOol00`00Oomoo`1>Ool00fj4
Oomoo`0AOomAO01TOol00fj4Oomoo`1OOol003aoo`03001oogoo04eoo`03KXAoogoo01=ooe1l0<Io
o`00?7oo00<007ooOol0C7oo00=^Q7ooOol05GooCg`0aWoo000lOol00`00Oomoo`1UOom>O01WOol0
0fj4Oomoo`1LOol003aoo`03001oogoo06Ioodel06Qoo`03KXAoogoo05]oo`00?7oo00<007ooOol0
BGoo00=^Q7ooOol06gooC7`0JGoo00=^Q7ooOol0FWoo000lOol00`00Oomoo`18Ool00fj4Oomoo`0M
Oom;O01ZOol00fj4Oomoo`1IOol003aoo`03001oogoo04Moo`03KXAoogoo01moodYl0<Ioo`00?7oo
00<007ooOol0AWoo00=^Q7ooOol08GooBG`0aWoo000lOol3001[Oom8O01]Ool00fj4Oomoo`1FOol0
03aoo`03001oogoo06aoodMl06ioo`03KXAoogoo05Eoo`00?7oo00<007ooOol0@goo00=^Q7ooOol0
9gooAW`0Kgoo00=^Q7ooOol0E7oo000lOol00`00Oomoo`12Ool00fj4Oomoo`0YOom5O01`Ool00fj4
Oomoo`1COol003aoo`03001oogoo045oo`03KXAoogoo02]oodAl0<Ioo`00?7oo00<007ooOol0@7oo
00=^Q7ooOol0;Goo@g`0aWoo000lOol00`00Oomoo`1aOom2O01cOol2KXAAOol003aoo`03001oogoo
079ood5l07Eoo`03KXAoogoo04ioo`00?7oo00<007ooOol0?Goo00=^Q7ooOol0<goo@7`0MWoo00=^
Q7ooOol0CGoo000lOol00`00Oomoo`0mOol00fj4Oomoo`0dOoloO01gOol00fj4Oomoo`1<Ool003ao
o`03001oogoo03aoo`03KXAoogoo03Ioocil0<Ioo`00?7oo00<007ooOol0>goo00=^Q7ooOol0>7oo
?G`0aWoo000lOol00`00Oomoo`0jOol00fj4Oomoo`0jOollO01jOol00fj4Oomoo`19Ool003aoo`03
001oogoo07Qooc]l07]oo`03KXAoogoo04Qoo`00?7oo00<007ooOol0NGoo>W`0O7oo00=^Q7ooOol0
Agoo000lOol00`00Oomoo`0gOol00fj4Oomoo`10OoliO01mOol00fj4Oomoo`16Ool003aoo`03001o
ogoo03Ioo`03KXAoogoo049oocQl0<Ioo`00?7oo00<007ooOol0=Goo00=^Q7ooOol0A7oo=g`0aWoo
000lOol3000dOol00fj4Oomoo`16OolfO020Ool00fj4Oomoo`13Ool003aoo`03001oogoo07ioocEl
085oo`03KXAoogoo049oo`00?7oo00<007ooOol0Ogoo=7`0PWoo00=^Q7ooOol0@Goo000lOol00`00
Oomoo`0aOol00fj4Oomoo`1<OolcO023Ool00fj4Oomoo`10Ool003aoo`03001oogoo031oo`03KXAo
ogoo04iooc9l0<Ioo`00?7oo00<007ooOol0;goo00=^Q7ooOol0D7oo<G`0aWoo000lOol00`00Oomo
o`0^Ool00fj4Oomoo`1BOol`O026Ool00fj4Oomoo`0mOol003aoo`03001oogoo08Aoobml08Ioo`03
KXAoogoo03eoo`00?7oo00<007ooOol0QGoo;W`0Qgoo00=^Q7ooOol0?7oo000lOol00`00Oomoo`0Z
Ool00fj4Oomoo`1IOolTO00COn1nOol00fj4Oomoo`0kOol003=ooa=@WR9oo`03KXAoogoo05]ooail
00Eoh0Ul00Yoo`9oh7eoo`03KXAoogoo03Yoo`00;goo6E2N7goo00=^Q7ooOol0GGoo6g`00WoP3W`0
37oo17oP]Woo000]OolPD9hIOol00fj4Oomoo`1OOolHO002On0@O00@Ool2On2dOol002YoobE@WWYo
oaEl009oh19l019oo`9oh7Qoo`03KXAoogoo03Moo`00:7oo:E2NNGoo4W`00WoP57`057oo0WoPMgoo
00=^Q7ooOol0=Woo000VOol]D9h@Ool00fj4Oomoo`1UOol?O002On0FO00FOol2On1fOol00fj4Oomo
o`0eOol002Aooc5@WPeoo`03KXAoogoo06Moo`al009oh1Ql01Qoo`9oh7Eoo`03KXAoogoo03Aoo`00
8Woo=E2N2Woo00=^Q7ooOol0JGoo2W`000=oh7`0O00067`06Woo00=oh7ooOol0ZGoo000QOolfD9h9
Ool00fj4Oomoo`1[Ool8O0000goPO01l000IO00KOol00goPOomoo`2XOol0025oocM@WWMoo`Il0003
On1l07`001Yl01aoo`9oh7Aoo`03KXAoogoo035oo`007goo>e2NMWoo17`000=oh7`0O0006g`07Woo
00=oh7ooOol0LWoo00=^Q7ooOol0<7oo000NOolmD9h2Ool00fj4Oomoo`1aOol2O0000goPO01l000L
O00NOol00goPOomoo`1cOol00fj4Oomoo`0_Ool001eoocm@WP03KXAoogoo079oo`9oh1ml01moo`9o
h7Aoo`03KXAoogoo02ioo`0077oo?e2N00=^Q52NOol0LWoo00=oh7ooOol07g`08Goo00=oh7ooOol0
XWoo000KOoloD9h016j4D9i@WU2NLWoo00Aoh7ooOomooail029oo`03On1oogoo0:5oo`006WooAE2N
L7oo00=oh7ooOol00goo7G`08goo00=oh7ooOol0LWoo00=^Q7ooOol0:goo000IOom6D9i`Ool00goP
Oomoo`04OolLO00SOol00goPOomoo`1cOol00fj4Oomoo`0ZOol001Uooci@WP03KXA@WU2N00I@WVio
o`03On1oogoo00Iooa]l02Aoo`03On1oogoo07=oo`03KXAoogoo02Uoo`0067oo?U2N00=^Q52ND9h0
252NK7oo00=oh7ooOol027oo6W`097oo00=oh7ooOol0M7oo00=^Q7ooOol0:7oo000GOolnD9h00fj4
D9i@WP0:D9iZOol00goPOomoo`0:OolIO00UOol00goPOomoo`2NOol001Iooci@WP03KXA@WU2N00]@
WVYoo`03On1oogoo00]ooaQl02Eoo`03On1oogoo09ioo`005WooCE2NJ7oo00=oh7ooOol03Goo5g`0
9Woo00=oh7ooOol0MGoo00=^Q7ooOol09Goo000EOom>D9iXOol00goPOomoo`0>OolFO00WOol00goP
Oomoo`1eOol00fj4Oomoo`0TOol001Eooca@WP03KXA@WU2N011@WVIoo`03On1oogoo011ooaEl02Qo
o`03On1oogoo07Eoo`03KXAoogoo02=oo`0057oo?52N00=^Q52ND9h04E2NIWoo00=oh7ooOol04Goo
57`0:7oo00=oh7ooOol0MWoo00=^Q7ooOol08Woo000DOolkD9h00fj4D9i@WP0CD9iTOol00goPOomo
o`0COolCO00YOol00goPOomoo`2JOol001=ooc]@WP03KXA@WU2N01A@WVAoo`03On1oogoo01Aooa9l
02Uoo`03On1oogoo09Yoo`004gooDe2NHWoo00=oh7ooOol05Woo4G`0:Woo00=oh7ooOol0Mgoo00=^
Q7ooOol07goo000BOomDD9iROol00goPOomoo`0GOol@O00ZOol00goPOomoo`1hOol00fj4Oomoo`0N
Ool0019oocU@WP03KXA@WU2N01U@WV1oo`03On1oogoo01Uoo`ml02Yoo`03On1oogoo07Uoo`03KXAo
ogoo01eoo`004Goo>E2N00=^Q52ND9h06U2NH7oo00=oh7ooOol06Woo3W`0:Woo00=oh7ooOol0NWoo
00=^Q7ooOol077oo000AOolhD9h00fj4D9i@WP0KD9iOOol00goPOomoo`0LOol=O00[Ool00goPOomo
o`2HOol0015oocM@WP03KXA@WU2N01a@WUmoo`03On1oogoo01eoo`al02]oo`03On1oogoo09Qoo`00
4GooEe2NGWoo00=oh7ooOol07Woo2g`0;7oo00=oh7ooOol0Ngoo00=^Q7ooOol06Goo000@OomHD9iN
Ool00goPOomoo`0OOol:O00/Ool00goPOomoo`1lOol00fj4Oomoo`0HOol0011oocE@WP03KXA@WU2N
025@WUaoo`03On1oogoo025oo`Ul02aoo`03On1oogoo07eoo`03KXAoogoo01Moo`003goo=E2N00=^
Q52ND9h08U2NG7oo00=oh7ooOol08Woo27`0;7oo00=oh7ooOol0OWoo00=^Q7ooOol05Woo000?Oold
D9h00fj4D9i@WP0SD9iLOol00goPOomoo`0SOol7O00]Ool00goPOomoo`2FOol000mooc=@WP03KXA@
WU2N02A@WUaoo`03On1oogoo02Aoo`Il02eoo`03On1oogoo09Ioo`003gooFU2NG7oo00=oh7ooOol0
9Goo1G`0;Goo00=oh7ooOol0P7oo00=^Q7ooOol04goo000?OomJD9iLOol00goPOomoo`0VOol4O00]
Ool00goPOomoo`21Ool00fj4Oomoo`0BOol000mooc1@WP03KXA@WU2N02M@WUaoo`03On1oogoo02Mo
o`=l02eoo`03On1oogoo089oo`03KXAoogoo015oo`003goo;e2N00=^Q52ND9h0:52NFgoo00=oh7oo
Ool0:Goo0W`0;Goo00=oh7ooOol0Pgoo00=^Q7ooOol047oo000?Ool^D9h00fj4D9i@WP0YD9iKOol0
0goPOomoo`0ZOol00g`0Oomoo`0[Ool00goPOomoo`2FOol000moobe@WP03KXA@WU2N02Y@WU]oo`03
On1oogoo05Qoo`03On1oogoo09Ioo`003gooFU2NFgoo00=oh7ooOol0F7oo00=oh7ooOol0QGoo00=^
Q7ooOol03Woo000?Ool^D9h00fj4D9i@WP0YD9iKOol00goPOomoo`1HOol00goPOomoo`24Ool00fj4
Oomoo`0?Ool000moobm@WP03KXA@WU2N02Q@WU]oo`03On1oogoo05Qoo`03On1oogoo08=oo`03KXAo
ogoo011oo`003goo<52N00=^Q52ND9h09e2NG7oo00=oh7ooOol0Egoo00=oh7ooOol0PWoo00=^Q7oo
Ool04Goo000?OolaD9h00fj4D9i@WP0VD9iLOol00goPOomoo`1GOol00goPOomoo`2FOol000mooeY@
WUaoo`03On1oogoo05Moo`03On1oogoo09Ioo`003gooFU2NG7oo00=oh7ooOol0Egoo00=oh7ooOol0
Ogoo00=^Q7ooOol057oo000?OoldD9h00fj4D9i@WP0SD9iLOol00goPOomoo`1GOol00goPOomoo`1n
Ool00fj4Oomoo`0EOol000moocE@WP03KXA@WU2N029@WUaoo`03On1oogoo05Ioo`03On1oogoo07io
o`03KXAoogoo01Ioo`003goo=U2N00=^Q52ND9h08E2NG7oo00=oh7ooOol0EWoo00=oh7ooOol0OGoo
00=^Q7ooOol05goo000@OolfD9h00fj4D9i@WP0PD9iMOol00goPOomoo`1EOol00goPOomoo`2GOol0
011ooeQ@WUioo`03On1oogoo05Eoo`03On1oogoo09Moo`004GooEe2NGWoo00=oh7ooOol0E7oo00=o
h7ooOol0NWoo00=^Q7ooOol06goo000AOolhD9h2KX@LD9iOOol00goPOomoo`1DOol00goPOomoo`1i
Ool00fj4Oomoo`0LOol0015oocY@WP03KXA@WU2N01U@WUmoo`03On1oogoo05Aoo`03On1oogoo07Qo
o`03KXAoogoo01eoo`004Goo>e2N00=^Q52ND9h0652NH7oo00=oh7ooOol0DWoo00=oh7ooOol0N7oo
00=^Q7ooOol07Woo000AOollD9h00fj4D9i@WP0GD9iPOol00goPOomoo`1BOol00goPOomoo`2IOol0
019ooeE@WV5oo`03On1oogoo055oo`03On1oogoo09Uoo`004WooE52NHWoo00=oh7ooOol0DGoo00=o
h7ooOol0MGoo00=^Q7ooOol08Goo000COolmD9h00fj4D9i@WP0CD9iSOol00goPOomoo`1?Ool00goP
Oomoo`1eOol00fj4Oomoo`0ROol001=ooci@WP03KXA@WU2N015@WVAoo`03On1oogoo04moo`03On1o
ogoo07Aoo`03KXAoogoo02=oo`0057oo?U2N00=^Q52ND9h0452NIGoo00=oh7ooOol0CGoo00=oh7oo
Ool0M7oo00=^Q7ooOol097oo000DOoloD9h00fj4D9i@WP0>D9iVOol00goPOomoo`1<Ool00goPOomo
o`2LOol001Eoodm@WVMoo`03On1oogoo04Yoo`03On1oogoo09eoo`005GooCU2NJ7oo00=oh7ooOol0
BWoo00=oh7ooOol0Lgoo00=^Q7ooOol09goo000FOom0D9h00fj4D9i@WP0:D9iYOol00goPOomoo`18
Ool00goPOomoo`1cOol00fj4Oomoo`0XOol001Mood1@WP03KXA@WU2N00Q@WVYoo`03On1oogoo04Qo
o`03On1oogoo079oo`03KXAoogoo02Uoo`0067oo@52N00=^Q52ND9h01U2NK7oo0WoPAgoo00=oh7oo
Ool0LWoo00=^Q7ooOol0:Woo000IOom0D9h00fj4D9i@WP04D9i_Ool00goPOomoo`13Ool00goPOomo
o`2POol001YoodE@WW1oo`03On1oogoo049oo`03On1oogoo0:5oo`006goo@e2NLWoo00=oh7ooOol0
@7oo00=oh7ooOol0LWoo00=^Q7ooOol0;Goo000KOom1D9h00fj4Oomoo`1bOol00goPOomoo`0nOol0
0goPOomoo`1bOol00fj4Oomoo`0^Ool001aood5@WP03KXAoogoo079oo`9oh3eoo`03On1oogoo079o
o`03KXAoogoo02moo`007Woo?E2N0goo00=^Q7ooOol0Lgoo00=oh7ooOol0>Goo00=oh7ooOol0LWoo
00=^Q7ooOol0<7oo000OOolkD9h5Ool00fj4Oomoo`1bOol00goPOomoo`0hOol00goPOomoo`2VOol0
021oocU@WWaoo`9oh3Ioo`9oh:Uoo`008Goo=e2NOgoo0WoP<Woo0WoPZgoo000SOolcD9h<Ool00fj4
Oomoo`1dOol00goPOomoo`0^Ool00goPOomoo`1eOol00fj4Oomoo`0cOol002Aooc5@WPioo`03KXAo
ogoo07Aoo`03On1oogoo02aoo`03On1oogoo07Eoo`03KXAoogoo03Aoo`009Goo;e2N47oo00=^Q7oo
Ool0M7oo0WoP:Woo0WoPMgoo00=^Q7ooOol0=Goo000WOol[D9hCOol00fj4Oomoo`1eOol2On0VOol2
On1hOol00fj4Oomoo`0fOol002UoobM@WXmoo`9oh29oo`9oh;=oo`00:goo8e2NTgoo17oP6Woo17oP
]Goo000`OolID9hOOol00fj4Oomoo`1jOol3On0EOol2On1mOol00fj4Oomoo`0iOol0039ooaE@WR9o
o`03KXAoogoo07aoo`Ioh0Qoo`Moh7ioo`03KXAoogoo03Yoo`00>Goo252N:Goo00=^Q7ooOol0PGoo
27oPQ7oo00=^Q7ooOol0>goo000lOol00`00Oomoo`0/Ool00fj4Oomoo`3oOol<Ool00fj4Oomoo`0l
Ool003aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`0_Ool0
0fj4Oomoo`3oOol6Ool00fj4Oomoo`0oOol003aoo`03001oogoo031oo`03KXAoogoo0?moo`Aoo`03
KXAoogoo041oo`00?7oo00<007ooOol0<Goo00=^Q7ooOol0ogoo0Woo00=^Q7ooOol0@Goo000lOol0
0`00Oomoo`0bOol00fj4Oomoo`3oOol00fj4Oomoo`12Ool003aoo`03001oogoo0?moogYoo`00?7oo
0`00ogooNWoo000lOol00`00Oomoo`0eOol00fj4Oomoo`3iOol00fj4Oomoo`15Ool003aoo`03001o
ogoo03Ioo`03KXAoogoo0?Moo`03KXAoogoo04Ioo`00?7oo00<007ooOol0=goo00=^Q7ooOol0mGoo
00=^Q7ooOol0Agoo000lOol00`00Oomoo`0hOol00fj4Oomoo`3cOol00fj4Oomoo`18Ool003aoo`03
001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`0kOol00fj4Oomoo`3]
Ool00fj4Oomoo`1;Ool003aoo`03001oogoo03aoo`03KXAoogoo0>]oo`03KXAoogoo04aoo`00?7oo
00<007ooOol0?Goo00=^Q7ooOol0jGoo00=^Q7ooOol0CGoo000lOol00`00Oomoo`0nOol00fj4Oomo
o`3WOol00fj4Oomoo`1>Ool003aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000l
Ool00`00Oomoo`11Ool00fj4Oomoo`3QOol00fj4Oomoo`1AOol003aoo`03001oogoo049oo`03KXAo
ogoo0=moo`03KXAoogoo059oo`00?7oo00<007ooOol0@goo00=^Q7ooOol0gGoo00=^Q7ooOol0Dgoo
000lOol00`00Oomoo`14Ool00fj4Oomoo`3KOol00fj4Oomoo`1DOol003aoo`03001oogoo0?moogYo
o`00?7oo0`00ogooNWoo000lOol00`00Oomoo`3oOolPOol00fj4Oomoo`1GOol003aoo`03001oogoo
04Moo`03KXAoogoo0=Aoo`03KXAoogoo05Qoo`00?7oo00<007ooOol0B7oo00=^Q7ooOol0dWoo00=^
Q7ooOol0FGoo000lOol00`00Oomoo`19Ool00fj4Oomoo`3@Ool00fj4Oomoo`1JOol003aoo`03001o
ogoo04Yoo`03KXAoogoo0?moobeoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`3oOolJ
Ool00fj4Oomoo`1MOol003aoo`03001oogoo04eoo`03KXAoogoo0<Qoo`03KXAoogoo05ioo`00?7oo
00<007ooOol0CWoo00=^Q7ooOol0aWoo00=^Q7ooOol0Ggoo000lOol00`00Oomoo`1?Ool00fj4Oomo
o`34Ool00fj4Oomoo`1POol003aoo`03001oogoo051oo`03KXAoogoo0?moobMoo`00?7oo00<007oo
Ool0ogooNWoo000lOol00`00Oomoo`3oOolDOol00fj4Oomoo`1SOol003aoo`03001oogoo05=oo`03
KXAoogoo03aoo`@007aoo`03KXAoogoo06Aoo`00?7oo00<007ooOol0E7oo00=^Q7ooOol0?7oo00<0
07ooOol0Ngoo00=^Q7ooOol0IGoo000VOol30004Ool20003Ool30007Ool00`00Oomoo`1EOol00fj4
Oomoo`0;Ool30004Ool30003Ool:0007Ool30003Ool200000goo00000002Ool30002Ool40009Ool3
0002Ool40008Ool40003Ool30002Ool40002Ool01P00Ool007oo001oo`D0009oo`<000Qoo`@000=o
o`<0009oo`@0009oo`@000=oo`@0009oo`@0009oo`8000ioo`03KXAoogoo06Ioo`009goo00<007oo
Ool00goo0P001Woo00<007ooOol017oo00<007ooOol0EWoo00=^Q7ooOol02Woo00@007ooOol0009o
o`07001oogooOol007oo00000goo00<007oo00000Woo00<007ooOol01Woo00@007ooOol0009oo`04
001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Eoo`05001oogooOol00002Ool0
0`00Oomoo`07Ool00`00Oomoo`04Ool01@00Oomoogoo000017oo00P007ooOol007oo001oo`000goo
00D007ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00002Ool00`00
Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2001gOol002Moo`03001o
ogoo00]oo`03001oogoo00Aoo`@006Aoo`80009oo`07001oogooOol007oo00000goo00<007oo0000
0`002Woo0P000Woo00@007ooOol0009oo`07001oogooOol007oo00000goo00<007ooOol01Goo00D0
07ooOomoo`00009oo`03001oogoo00Moo`03001oogoo00Aoo`06001oogooOol007oo10000Woo00D0
07oo001oo`0000=oo`05001oogooOol0000:Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<0
07ooOol00goo00<007ooOol00Woo1@0000=oo`0000000`00Ngoo000WOol00`00Oomoo`08Ool30007
Ool00`00Oomoo`1SOol20004Ool01`00Oomoogoo001oo`0000=oo`03001oogoo009oo`03001oogoo
00Ioo`8000Aoo`04001oogoo0002Ool01`00Oomoogoo001oo`0000=oo`03001oogoo00Eoo`05001o
ogooOol00002Ool20008Ool00`00Oomoo`04Ool01`00Oomoogoo001oo`0000Eoo`05001oo`00Ool0
0003Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`00009o
o`03001oogoo00=oo`03001oogoo009oo`07001oogooOol007oo00000goo00D007ooOomoo`0000]o
o`03KXAoogoo06Uoo`009goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0FGoo00=^Q7oo
Ool01goo00@007ooOol000=oo`<000=oo`@0009oo`<000Qoo`04001oogoo0002Ool40003Ool30000
0goo000000030009Ool30002Ool200000goo00000006Ool01@00Oomoogoo00000goo0`000Woo1000
00=oo`00000010000Woo0P0017oo10001Woo00D007ooOomoo`0000=oo`<0009oo`@0009oo`@000=o
o`<000=oo`<0009oo`04001oogoo0009Ool00fj4Oomoo`1ZOol002Ioo`8000Yoo`@000Ioo`03001o
ogoo05Yoo`03KXAoogoo00Moo`<000aoo`03001oogoo00aoo`<0009oo`03001oogoo02Moo`@002Io
o`@000Uoo`03001oogoo00=oo`03001oogoo00ioo`@000Qoo`03KXAoogoo06]oo`00?7oo00<007oo
Ool0Fgoo00=^Q7ooOol057oo0P004Woo0P00@goo00<007ooOol06Woo0`000goo0`006Goo00=^Q7oo
Ool0K7oo000lOol00`00Oomoo`1LOol00fj4Oomoo`3oOolKOol003aoo`03001oogoo0?moogYoo`00
?7oo00<007ooOol0ogoo1goo00=^Q7ooOol0L7oo000lOol00`00Oomoo`1OOol2KXBTOol00fj4Oomo
o`1aOol003aoo`03001oogoo065oo`03KXAoogoo0:1oo`03KXAoogoo079oo`00?7oo00<007ooOol0
HWoo00=^Q7ooOol0WWoo00=^Q7ooOol0Lgoo000lOol00`00Oomoo`1SOol00fj4Oomoo`3oOolDOol0
03aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogoo0Goo00=^Q7ooOol0MWoo000lOol00`00
Oomoo`1VOol00fj4Oomoo`2FOol00fj4Oomoo`1gOol003aoo`03001oogoo06Moo`03KXAoogoo09Ao
o`03KXAoogoo07Qoo`00?7oo00<007ooOol0J7oo00=^Q7ooOol0TWoo00=^Q7ooOol0NGoo000lOol0
0`00Oomoo`1YOol00fj4Oomoo`3oOol>Ool003aoo`<00?moogYoo`00?7oo00<007ooOol0nWoo00=^
Q7ooOol0O7oo000lOol00`00Oomoo`1/Ool00fj4Oomoo`2:Ool00fj4Oomoo`1mOol003aoo`03001o
ogoo06eoo`03KXAoogoo08Qoo`03KXAoogoo07ioo`00?7oo00<007ooOol0KWoo00=^Q7ooOol0QWoo
00=^Q7ooOol0Ogoo000lOol00`00Oomoo`1_Ool00fj4Oomoo`3oOol8Ool003aoo`03001oogoo0?mo
ogYoo`00?7oo00<007ooOol0m7oo00=^Q7ooOol0PWoo000lOol00`00Oomoo`1bOol00fj4Oomoo`1n
Ool00fj4Oomoo`23Ool003aoo`03001oogoo07=oo`03KXAoogoo07aoo`03KXAoogoo08Aoo`00?7oo
00<007ooOol0M7oo00=^Q7ooOol0NWoo00=^Q7ooOol0QGoo000lOol00`00Oomoo`1eOol00fj4Oomo
o`3oOol2Ool003aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomo
o`1hOol00fj4Oomoo`1cOol00fj4Oomoo`28Ool003aoo`03001oogoo07Uoo`03KXAoogoo075oo`03
KXAoogoo08Uoo`00?7oo00<007ooOol0NWoo00=^Q7ooOol0Kgoo00=^Q7ooOol0RWoo000lOol00`00
Oomoo`1kOol00fj4Oomoo`1]Ool00fj4Oomoo`2;Ool003aoo`<00?moogYoo`00?7oo00<007ooOol0
ogooNWoo000lOol00`00Oomoo`1nOol00fj4Oomoo`1WOol00fj4Oomoo`2>Ool003aoo`03001oogoo
07moo`03KXAoogoo06Eoo`03KXAoogoo08moo`00?7oo00<007ooOol0P7oo00=^Q7ooOol0Hgoo00=^
Q7ooOol0T7oo000lOol00`00Oomoo`21Ool00fj4Oomoo`1QOol00fj4Oomoo`2AOol003aoo`03001o
ogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`24Ool00fj4Oomoo`1KOol0
0fj4Oomoo`2DOol003aoo`03001oogoo08Eoo`03KXAoogoo05Uoo`03KXAoogoo09Eoo`00?7oo00<0
07ooOol0QWoo00=^Q7ooOol0Egoo00=^Q7ooOol0UWoo000lOol00`00Oomoo`27Ool00fj4Oomoo`1E
Ool00fj4Oomoo`2GOol003aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol0
0`00Oomoo`2:Ool00fj4Oomoo`1?Ool00fj4Oomoo`2JOol003aoo`03001oogoo08]oo`03KXAoogoo
04eoo`03KXAoogoo09]oo`00?7oo00<007ooOol0S7oo00=^Q7ooOol0Bgoo00=^Q7ooOol0W7oo000l
Ool00`00Oomoo`2=Ool00fj4Oomoo`19Ool00fj4Oomoo`2MOol003aoo`03001oogoo0?moogYoo`00
?7oo0`00ogooNWoo000lOol00`00Oomoo`2@Ool00fj4Oomoo`13Ool00fj4Oomoo`2POol003aoo`03
001oogoo095oo`03KXAoogoo045oo`03KXAoogoo0:5oo`00?7oo00<007ooOol0TWoo00=^Q7ooOol0
?goo00=^Q7ooOol0XWoo000lOol00`00Oomoo`2COol00fj4Oomoo`0mOol00fj4Oomoo`2SOol003ao
o`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`2FOol00fj4Oomo
o`0gOol00fj4Oomoo`2VOol003aoo`03001oogoo09Moo`03KXAoogoo03Eoo`03KXAoogoo0:Moo`00
?7oo00<007ooOol0V7oo00=^Q7ooOol0<goo00=^Q7ooOol0Z7oo000lOol00`00Oomoo`2IOol00fj4
Oomoo`0aOol00fj4Oomoo`2YOol003aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo
000lOol00`00Oomoo`3:Ool00fj4Oomoo`2/Ool003aoo`03001oogoo09aoo`03KXAoogoo02Yoo`03
KXAoogoo0:eoo`00?7oo00<007ooOol0WGoo00=^Q7ooOol0:7oo00=^Q7ooOol0[Woo000lOol00`00
Oomoo`2NOol00fj4Oomoo`0VOol00fj4Oomoo`2_Ool003aoo`03001oogoo09moo`03KXAoogoo0=Mo
o`00?7oo0`00ogooNWoo000lOol00`00Oomoo`34Ool00fj4Oomoo`2bOol003aoo`03001oogoo0:9o
o`03KXAoogoo01ioo`03KXAoogoo0;=oo`00?7oo00<007ooOol0Xgoo00=^Q7ooOol077oo00=^Q7oo
Ool0]7oo000lOol00`00Oomoo`2TOol00fj4Oomoo`0JOol00fj4Oomoo`2eOol003aoo`03001oogoo
0:Eoo`03KXAoogoo0=5oo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`2nOol00fj4Oomo
o`2hOol003aoo`03001oogoo0:Qoo`03KXAoogoo019oo`03KXAoogoo0;Uoo`00?7oo00<007ooOol0
ZGoo00=^Q7ooOol047oo00=^Q7ooOol0^Woo000lOol00`00Oomoo`2ZOol00fj4Oomoo`0>Ool00fj4
Oomoo`2kOol003aoo`03001oogoo0:]oo`03KXAoogoo0<]oo`00?7oo00<007ooOol0ogooNWoo000l
Ool00`00Oomoo`2gOol2KXC0Ool003aoo`03001oogoo0:ioo`03KXAoogoo00Eoo`03KXAoogoo0<1o
o`00?7oo00<007ooOol0[goo00=^Q7ooOol00goo00=^Q7ooOol0`Goo000bOol40006Ool00`00Oomo
o`2`Ool01Fj4OomoogooKX@0a7oo000cOol00`00Oomoo`06Ool00`00Oomoo`2aOol00fj4Oomoo`35
Ool003Aoo`03001oogoo00Eoo`@00?moogUoo`00=Goo00<007ooOol017oo00<007ooOol0ogooNWoo
000bOol01000Oomoo`001Woo00<007ooOol0ogooNWoo000cOol20007Ool00`00Oomoo`3oOomjOol0
03aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`3oOomjOol0
03aoo`03001oogoo0?moogYoo`00?7oo00<007ooOol0ogooNWoo000lOol00`00Oomoo`3oOomjOol0
0001\
\>"],
  ImageRangeCache->{{{0, 439}, {388, 0}} -> {-0.332778, -0.0825558, 
  0.00550241, 0.00550241}}],

Cell[TextData[{
  StyleBox[
  "We will build up the pieces of this picture one at a time and then use \"",
    
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Show[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to display them at the same time.  First, we must tell ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " that we will need the package of color definitions.  This command should \
be executed only once, before any other cells using color names are executed, \
so that no color names will be defined in the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Global`",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" context before these definitions are executed.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Needs[\"Graphics`Colors`\"]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"If we want to see all the colors we can use, we can execute the following \
cell."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["?Graphics`Colors`*"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["In order to create the red triangle, we will use our first ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["graphics primitive",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ".  A graphics primitive is a symbolic graphics command, which for \
2-dimensional graphics are chosen from \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Point[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Line[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Rectangle[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Polygon[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Circle[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Disk[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Raster[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Text[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  We will also use a ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["graphics directive",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  ", which for us will either be a color command or a \"dashing \
instruction\", which we will define below.  The difference between primitives \
and directives lies in the fact that graphics primitives describe particular \
geometric objects,while graphics directives specify only characteristics of \
succeeding primitives.  If we place graphics primitives and directives \
together in a list, the graphics directives set the characteristics for all \
succeeding primitives (unless another directive which negates the action is \
encountered).  After we create a list of primitives and directives, we will \
need two commands which will actually create the graphics based on the \
commands in our list.  One command is needed for each of the two stages of \
the process.  The first command, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Graphics[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", converts graphics directives and primitives into ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  "'s own internal commands for the graphics.  However, this command does not \
display the graphics.  The second command, \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Show[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", takes the internal commands created by \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Graphics[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" and actually displays them in a cell.  It is important that we store \
the result of \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Graphics[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", these internal commands, in some variable, so that we can execute \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Show[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" with this variable as a parameter.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "We build up the picture as follows.  Our red triangle is formed by first \
issuing the graphics directive \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Red",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", followed by the graphics primitive \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Polygon[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which takes as its argument a list of x-y pairs, thought of as the \
vertices of the polygon.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"redTriangle=Graphics[{Red,Polygon[{{0,0},{1,0},{1,1}}]}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"We'll now define a disk (a filled-in circle) and a circle.  These primitives \
require two arguments, an x-y pair, followed by the radius of the circle."], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["purpleDisk=Graphics[{Purple,Disk[{0,1},.25]}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData["yellowCircle=Graphics[{Yellow,Circle[{1,1},.25]}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "We may display any combination of our primitives now by using the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Show[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" command.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["Show[redTriangle, purpleDisk, yellowCircle]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Our primitives appear squashed because of the default \"aspect ratio\", \
which forces the \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["y",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" axis to be scaled in accordance with \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  To circumvent this, we can tell ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " to figure out the correct aspect ratio to display x-y points with even \
scaling in the x and y directions, using the option \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["AspectRatio->Automatic",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Show[redTriangle, purpleDisk, yellowCircle,\n   AspectRatio->Automatic\n]"], 
  "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "Now we will construct a box, where the lines are not solid but are \
\"dashed\", using a separate graphics directive \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dashing[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\".  This directive requires as arguments a list of lengths for the dashed \
segments of the line; the list will be repeated over and over to determine \
the length of each dashed piece.  Giving \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Dashing[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" a list with one element, then, specifies that the dashing segments will \
all be of the same length.  Our graphics primitive is \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Line[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which requires a list of x-y pairs to connect; note that we close off \
the list with the same point we began with.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"box=Graphics[{Goldenrod,Dashing[{.01}],\n    \
Line[{{0,1},{1,0},{2,1},{1,2},{0,1}}]}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Finally we introduce some text, using the graphics primitive \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Text[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\", which takes as arguments a string to be printed and an x-y pair \
describing the coordinate at which the text should be centered.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"tagLine=Graphics[{Text[\"Soda Shop or Cosmic Coffee?\",{1,1.5}]}]"], "Input",\

  AspectRatioFixed->True],

Cell[TextData["Voila!"], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"masterPiece = Show[\n  redTriangle,purpleDisk,yellowCircle,box,tagLine,\n  \
Axes->True,\n  AspectRatio->Automatic\n]"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Adding Plots to Graphics"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Suppose we want to add the graphics resulting from a plot command to a \
picture we have built up using graphics primitives.  We need only capture the \
internal representations of the graphics, by assigning the results of the \
\"Graphics[]\" command and the \"Plot[]\" or \"ListPlot[]\" command to \
separate variables, and we then use \"Show[]\" to display all of the graphics \
together."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData["sine = Plot[1+Sin[Pi x],{x,0,2}]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"This command actually shows the graph, but remember that we can suppress the \
immediate display by using the \"DisplayFunction->Identity\" option.  \
Remember to use \"DisplayFunction-> $DisplayFunction\" with the \"Show[]\" \
command."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"minusSine = Plot[1-Sin[Pi*x],{x,0,2}, \n   DisplayFunction->Identity] "], 
  "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Show[masterPiece, sine, minusSine,\n   DisplayFunction->$DisplayFunction]"], 
  "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Adding Graphics to Plots"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Alternatively, we can attempt to add graphics to the result of the \
\"Plot[]\" command.  We can do so using the options \"Prolog[]\" or \
\"Epilog[]\", which provide \"Plot[]\" with some graphics primitives it must \
display both before and after the original plot.  We do not need to use the \
\"Graphics[]\" function."], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Plot[1+Sin[Pi x],{x,0,2}, \n   Epilog->\n      {Purple,\n       \
Disk[{0,1},.25],\n       Red,\n       Circle[{1,1},.25]}\n]"], "Input",
  AspectRatioFixed->True],

Cell[TextData[
"Let's change \"Epilog\" to \"Prolog\".  Is there a difference?  Why?"], 
  "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[
"Plot[1+Sin[Pi x],{x,0,2}, \n   Prolog->\n      {Purple,\n       \
Disk[{0,1},.25],\n       Red,\n       Circle[{1,1},.25]}\n]"], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData["Further Study"], "Subsection",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox[
  "The wealth of graphics primitives and directives is too large for us to \
consider exhaustively here.  However, here are some tips you may wish to \
remember when using \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" or some other plot command.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["The option \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotStyle->{ }",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox[
  "\" provides a way for graphics directives to be issued before a function \
is plotted.  If the list contains sublists, then sublists of directives are \
used, one at a time, for each function.  To plot \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x^2",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in red and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["x^3",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" in green, then, we could issue the command \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Plot[{x^2,x^3},PlotStyle->{{Red},{Green}}]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Other directives include \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GrayLevel[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", for gray-scale \"color\", and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Thickness[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\", to alter the widths of the lines drawn.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Options for plot commands also include \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Axes->",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["boolean",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["\" to decide whether or not to draw the axes; \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["GridLines->...",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for drawing gridlines, and \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["PlotLabel->\"text\"",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" to assign a label to the plot.  Consult \"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Options[Plot]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\" for more information.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Finally, ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[
  " easily plots three-dimensional graphs using 3-D graphics primitives and \
\"",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Graphics3D[]",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontFamily->"Courier"],
  StyleBox["\".  Consult ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Introduction to Programming with Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[", chapter 10, or the ",
    Evaluatable->False,
    AspectRatioFixed->True],
  StyleBox["Mathematica",
    Evaluatable->False,
    AspectRatioFixed->True,
    FontSlant->"Italic"],
  StyleBox[" reference manual, for further study.",
    Evaluatable->False,
    AspectRatioFixed->True]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True]
}, Closed]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"Macintosh 3.0",
ScreenRectangle->{{0, 832}, {0, 604}},
WindowToolbars->{},
WindowSize->{520, 509},
WindowMargins->{{156, Automatic}, {15, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, 2},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003809T?o>old</PW30fL5:0?l0080004/0B`000000]P2:001
0000I00000400`<300000BL?00400@5caU0000000000060801T1T000000`0000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 102, 2, 98, "Title",
  Evaluatable->False],
Cell[1836, 55, 97, 2, 98, "Title",
  Evaluatable->False],
Cell[1936, 59, 98, 2, 26, "SmallText",
  Evaluatable->False],
Cell[2037, 63, 215, 7, 32, "Text",
  Evaluatable->False],
Cell[2255, 72, 1786, 66, 138, "SmallText",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4066, 142, 81, 2, 50, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[4172, 148, 101, 2, 46, "Subsection",
  Evaluatable->False],
Cell[4276, 152, 1024, 32, 98, "Text",
  Evaluatable->False],
Cell[5303, 186, 620, 10, 200, "Input"],
Cell[5926, 198, 645, 18, 51, "Text",
  Evaluatable->False],
Cell[6574, 218, 146, 3, 40, "Input"],
Cell[6723, 223, 81, 1, 22, "Input"],
Cell[6807, 226, 1261, 31, 103, "Text",
  Evaluatable->False],
Cell[8071, 259, 210, 4, 38, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[8318, 268, 126, 2, 42, "Subsection",
  Evaluatable->False],
Cell[8447, 272, 1106, 34, 64, "Text",
  Evaluatable->False],
Cell[9556, 308, 57, 1, 22, "Input"],
Cell[9616, 311, 1714, 59, 64, "Text",
  Evaluatable->False],
Cell[11333, 372, 90, 1, 22, "Input"],
Cell[11426, 375, 2239, 81, 64, "Text",
  Evaluatable->False],
Cell[13668, 458, 92, 1, 22, "Input"],
Cell[13763, 461, 491, 16, 38, "Text",
  Evaluatable->False],
Cell[14257, 479, 136, 3, 40, "Input"],
Cell[14396, 484, 183, 4, 25, "Text",
  Evaluatable->False],
Cell[14582, 490, 78, 1, 22, "Input"],
Cell[14663, 493, 462, 15, 38, "Text",
  Evaluatable->False],
Cell[15128, 510, 77, 1, 22, "Input"],
Cell[15208, 513, 92, 1, 22, "Input"],
Cell[15303, 516, 110, 2, 30, "Input"],
Cell[15416, 520, 78, 1, 22, "Input"],
Cell[15497, 523, 858, 29, 38, "Text",
  Evaluatable->False],
Cell[16358, 554, 256, 4, 70, "Input"],
Cell[16617, 560, 1095, 36, 51, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17761, 602, 97, 2, 30, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17883, 608, 114, 2, 42, "Subsection",
  Evaluatable->False],
Cell[18000, 612, 26974, 650, 317, 3363, 353, "GraphicsData", 
"PostScript", "Graphics",
  Evaluatable->False],
Cell[44977, 1264, 1048, 32, 64, "Text",
  Evaluatable->False],
Cell[46028, 1298, 80, 1, 22, "Input"],
Cell[46111, 1301, 156, 4, 25, "Text",
  Evaluatable->False],
Cell[46270, 1307, 71, 1, 22, "Input"],
Cell[46344, 1310, 4358, 136, 194, "Text",
  Evaluatable->False],
Cell[50705, 1448, 732, 24, 38, "Text",
  Evaluatable->False],
Cell[51440, 1474, 110, 2, 22, "Input"],
Cell[51553, 1478, 230, 5, 38, "Text",
  Evaluatable->False],
Cell[51786, 1485, 98, 1, 22, "Input"],
Cell[51887, 1488, 102, 1, 22, "Input"],
Cell[51992, 1491, 393, 14, 25, "Text",
  Evaluatable->False],
Cell[52388, 1507, 96, 1, 22, "Input"],
Cell[52487, 1510, 1136, 38, 51, "Text",
  Evaluatable->False],
Cell[53626, 1550, 130, 3, 40, "Input"],
Cell[53759, 1555, 1235, 36, 77, "Text",
  Evaluatable->False],
Cell[54997, 1593, 140, 3, 30, "Input"],
Cell[55140, 1598, 510, 15, 38, "Text",
  Evaluatable->False],
Cell[55653, 1615, 121, 3, 22, "Input"],
Cell[55777, 1620, 80, 2, 25, "Text",
  Evaluatable->False],
Cell[55860, 1624, 171, 3, 60, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[56068, 1632, 104, 2, 42, "Subsection",
  Evaluatable->False],
Cell[56175, 1636, 466, 8, 51, "Text",
  Evaluatable->False],
Cell[56644, 1646, 85, 1, 22, "Input"],
Cell[56732, 1649, 311, 6, 38, "Text",
  Evaluatable->False],
Cell[57046, 1657, 127, 3, 30, "Input"],
Cell[57176, 1662, 130, 3, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[57343, 1670, 104, 2, 42, "Subsection",
  Evaluatable->False],
Cell[57450, 1674, 395, 7, 51, "Text",
  Evaluatable->False],
Cell[57848, 1683, 179, 3, 80, "Input"],
Cell[58030, 1688, 146, 4, 25, "Text",
  Evaluatable->False],
Cell[58179, 1694, 179, 3, 80, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[58395, 1702, 93, 2, 42, "Subsection",
  Evaluatable->False],
Cell[58491, 1706, 515, 16, 38, "Text",
  Evaluatable->False],
Cell[59009, 1724, 1143, 37, 51, "Text",
  Evaluatable->False],
Cell[60155, 1763, 596, 20, 38, "Text",
  Evaluatable->False],
Cell[60754, 1785, 1163, 39, 51, "Text",
  Evaluatable->False],
Cell[61920, 1826, 1026, 36, 38, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

